vcgezq_f16

Function vcgezq_f16 

1.94.0 · Source
pub fn vcgezq_f16(a: float16x8_t) -> uint16x8_t
Available on (AArch64 or ARM64EC) and non-ARM64EC and target feature neon and target feature fp16 only.
Floating-point compare greater than or equal to zero Arm’s documentation