pub fn vcombine_f64(a: float64x1_t, b: float64x1_t) -> float64x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Join two smaller vectors into a single larger vector Arm’s documentation
pub fn vcombine_f64(a: float64x1_t, b: float64x1_t) -> float64x2_tneon only.Join two smaller vectors into a single larger vector Arm’s documentation