pub fn vcombine_u32(a: uint32x2_t, b: uint32x2_t) -> uint32x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Join two smaller vectors into a single larger vector Arm’s documentation
pub fn vcombine_u32(a: uint32x2_t, b: uint32x2_t) -> uint32x4_tneon only.Join two smaller vectors into a single larger vector Arm’s documentation