pub fn vcvtms_u32_f32(a: f32) -> u32Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to unsigned integer, rounding toward minus infinity Arm’s documentation
pub fn vcvtms_u32_f32(a: f32) -> u32neon only.Floating-point convert to unsigned integer, rounding toward minus infinity Arm’s documentation