pub fn vcvtnd_u64_f64(a: f64) -> u64Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to unsigned integer, rounding to nearest with ties to even Arm’s documentation
pub fn vcvtnd_u64_f64(a: f64) -> u64neon only.Floating-point convert to unsigned integer, rounding to nearest with ties to even Arm’s documentation