pub fn vcvtxd_f32_f64(a: f64) -> f32Available on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Floating-point convert to lower precision narrow, rounding to odd Arm’s documentation
pub fn vcvtxd_f32_f64(a: f64) -> f32neon only.Floating-point convert to lower precision narrow, rounding to odd Arm’s documentation