vrndxh_f16

Function vrndxh_f16 

pub fn vrndxh_f16(a: f16) -> f16
🔬This is a nightly-only experimental API. (stdarch_neon_f16 #136306)
Available on (AArch64 or ARM64EC) and non-ARM64EC and target feature neon and target feature fp16 only.
Floating-point round to integral, using current rounding mode Arm’s documentation