vrndxq_f16

Function vrndxq_f16 

1.94.0 · Source
pub fn vrndxq_f16(a: float16x8_t) -> float16x8_t
Available on (AArch64 or ARM64EC) and non-ARM64EC and target feature neon and target feature fp16 only.
Floating-point round to integral exact, using current rounding mode Arm’s documentation