This type is the same as the __m128i type defined in lsxintrin.h,
representing a 128-bit SIMD register. Usage of this type typically
occurs in conjunction with the lsx and higher target features for
LoongArch.
Internally this type may be viewed as:
i8x16 - sixteen i8 values packed together
i16x8 - eight i16 values packed together
i32x4 - four i32 values packed together
i64x2 - two i64 values packed together
(as well as unsigned versions). Each intrinsic may interpret the
internal bits differently, check the documentation of the intrinsic
to see how itโs being used.
The in-memory representation of this type is the same as the one of an
equivalent array (i.e. the in-memory order of elements is the same, and
there is no padding); however, the alignment is different and equal to
the size of the type. Note that the ABI for function calls may not be
the same.
Note that this means that an instance of m128i typically just means
a โbag of bitsโ which is left up to interpretation at the point of use.
Most intrinsics using m128i are prefixed with lsx_ and the integer
types tend to correspond to suffixes like โbโ, โhโ, โwโ or โdโ.