pub fn _mm512_maskz_broadcastw_epi16(k: __mmask32, a: __m128i) -> __m512iAvailable on x86 and target feature
avx512bw and (x86 or x86-64) only.Expand description
Broadcast the low packed 16-bit integer from a to all elements of dst using zeromask k (elements are zeroed out when the corresponding mask bit is not set).