__tile_cvtrowd2ps

Function __tile_cvtrowd2ps 

pub unsafe fn __tile_cvtrowd2ps(src: __tile1024i, row: u32) -> __m512
🔬This is a nightly-only experimental API. (x86_amx_intrinsics #126622)
Available on x86-64 and target feature amx-avx512 and target feature avx10.2 only.
Moves a row from a tile register to a zmm register, converting the packed 32-bit signed integer elements to packed single-precision (32-bit) floating-point elements. The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.