__tile_dpbf16ps

Function __tile_dpbf16ps 

pub unsafe fn __tile_dpbf16ps(
    dst: *mut __tile1024i,
    a: __tile1024i,
    b: __tile1024i,
)
🔬This is a nightly-only experimental API. (x86_amx_intrinsics #126622)
Available on x86-64 and target feature amx-bf16 only.
Compute dot-product of FP16 (16-bit) floating-point pairs in tiles a and b, accumulating the intermediate single-precision (32-bit) floating-point elements with elements in dst, and store the 32-bit result back to tile dst. The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.

Intel’s documentation