pub unsafe fn __tile_dpbhf8ps(
dst: *mut __tile1024i,
a: __tile1024i,
b: __tile1024i,
)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-fp8 only.Expand description
Compute dot-product of BF8 (8-bit E5M2) floating-point elements in tile a and HF8
(8-bit E4M3) floating-point elements in tile b, accumulating the intermediate single-precision
(32-bit) floating-point elements with elements in dst, and store the 32-bit result
back to tile dst.
The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.