pub unsafe fn __tile_dpbusd(
dst: *mut __tile1024i,
a: __tile1024i,
b: __tile1024i,
)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-int8 only.Expand description
Compute dot-product of bytes in tiles with a source/destination accumulator.
Multiply groups of 4 adjacent pairs of unsigned 8-bit integers in a with corresponding
signed 8-bit integers in b, producing 4 intermediate 32-bit results.
Sum these 4 results with the corresponding 32-bit integer in dst, and store the 32-bit result back to tile dst.
The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.