pub unsafe fn __tile_stored(base: *mut u8, stride: usize, src: __tile1024i)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-tile only.Expand description
Store the tile specified by src to memory specified by base address and stride. The shape of the tile
is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.