__tile_stream_loadd

Function __tile_stream_loadd 

pub unsafe fn __tile_stream_loadd(
    dst: *mut __tile1024i,
    base: *const u8,
    stride: usize,
)
🔬This is a nightly-only experimental API. (x86_amx_intrinsics #126622)
Available on x86-64 and target feature amx-tile only.
Load tile rows from memory specified by base address and stride into destination tile dst. The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler. This intrinsic provides a hint to the implementation that the data will likely not be reused in the near future and the data caching can be optimized accordingly.

Intel’s documentation