pub unsafe fn __tile_zero(dst: *mut __tile1024i)🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-tile only.Expand description
Zero the tile specified by dst. The shape of the tile is specified in the struct of __tile1024i.
The register of the tile is allocated by the compiler.