pub fn _mm512_lzcnt_epi32(a: __m512i) -> __m512iAvailable on x86-64 and (x86 or x86-64) and target feature
avx512cd only.Expand description
Counts the number of leading zero bits in each packed 32-bit integer in a, and store the results in dst.