_mm_clflush

Function _mm_clflush 

1.27.0 · Source
pub unsafe fn _mm_clflush(p: *const u8)
Available on x86-64 and target feature sse2 and (x86 or x86-64) only.
Invalidates and flushes the cache line that contains p from all levels of the cache hierarchy.

Intel’s documentation

Safety

Unlike the prefetch intrinsics, CLFLUSH is subject to all the permission checking and faults associated with a byte load, so p must point to a byte that is valid for reads.