async fn run_camera_phototaking_loop(
camera: CameraHandle,
shutdown_token: CancellationToken,
)Expand description
Internal function which actually runs the actual camera phototaking infinite loop.
async fn run_camera_phototaking_loop(
camera: CameraHandle,
shutdown_token: CancellationToken,
)Internal function which actually runs the actual camera phototaking infinite loop.