struct Camera {
receiver: Receiver<CameraMessage>,
pool: PgPool,
a8mini: A8Mini,
sauron: Option<SauronHandle>,
}Expand description
The Camera Actor
Fields
receiver: Receiver<CameraMessage>pool: PgPoola8mini: A8Minisauron: Option<SauronHandle>Implementations
Sourceimpl Camera
impl Camera
Sourceasync fn new(receiver: Receiver<CameraMessage>) -> Self
async fn new(receiver: Receiver<CameraMessage>) -> Self
Create a new instance of Camera Actor.
This is an internal constructor, to create a Camera actor, call CameraHandle::new().
Sourceasync fn handle_message(&mut self, msg: CameraMessage) -> Result<()>
async fn handle_message(&mut self, msg: CameraMessage) -> Result<()>
Process a message received by the Camera actor.
Sourceasync fn take_photo(&self) -> Result<()>
async fn take_photo(&self) -> Result<()>
Calls the A8Mini API to take a photo and send the filepath to Sauron