Trait CloneFromCell
unsafe trait CloneFromCell: Clone
Types for which cloning Cell<Self> is sound.
Safety
Implementing this trait for a type is sound if and only if the following code is sound for T = that type.
# use ;
Importantly, you can't just implement CloneFromCell for any arbitrary Copy type, e.g. the
following is unsound:
# use Cell;
;
// this is not sound
// unsafe impl CloneFromCell for Bad<'_> {}
Implementors
impl<T: CloneFromCell, N: usize> CloneFromCell for [T; N]impl<T: CloneFromCell> CloneFromCell for Option<T>impl<T: CloneFromCell, E: CloneFromCell> CloneFromCell for Result<T, E>impl<T: CloneFromCell> CloneFromCell for Range<T>impl<T: CloneFromCell> CloneFromCell for Range<T>impl<T: CloneFromCell> CloneFromCell for (T)impl<T: ?Sized> CloneFromCell for PhantomData<T>impl<T: CloneFromCell> CloneFromCell for ManuallyDrop<T>