Struct DecodeUtf16Error

struct DecodeUtf16Error { ... }

An error that can be returned when decoding UTF-16 code points.

This struct is created when using the DecodeUtf16 type.

Implementations

impl DecodeUtf16Error

fn unpaired_surrogate(self: &Self) -> u16

Returns the unpaired surrogate which caused this error.

impl Clone for DecodeUtf16Error

fn clone(self: &Self) -> DecodeUtf16Error

impl Debug for DecodeUtf16Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DecodeUtf16Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for DecodeUtf16Error

impl Error for DecodeUtf16Error

impl Freeze for DecodeUtf16Error

impl PartialEq for DecodeUtf16Error

fn eq(self: &Self, other: &DecodeUtf16Error) -> bool

impl RefUnwindSafe for DecodeUtf16Error

impl Send for DecodeUtf16Error

impl StructuralPartialEq for DecodeUtf16Error

impl Sync for DecodeUtf16Error

impl Unpin for DecodeUtf16Error

impl UnsafeUnpin for DecodeUtf16Error

impl UnwindSafe for DecodeUtf16Error

impl<T> Any for DecodeUtf16Error

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DecodeUtf16Error

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DecodeUtf16Error

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DecodeUtf16Error

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DecodeUtf16Error

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DecodeUtf16Error

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DecodeUtf16Error

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DecodeUtf16Error

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>