Trait VaArgSafe
unsafe trait VaArgSafe: sealed::Sealed
Types that are valid to read using VaList::arg.
Safety
The standard library implements this trait for primitive types that are expected to have a variable argument application-binary interface (ABI) on all platforms.
When C passes variable arguments, integers smaller than c_int and floats smaller
than c_double are implicitly promoted to c_int and c_double respectively.
Implementing this trait for types that are subject to this promotion rule is invalid.
Implementors
impl VaArgSafe for usizeimpl VaArgSafe for u64impl VaArgSafe for u32impl VaArgSafe for isizeimpl<T> VaArgSafe for *const Timpl VaArgSafe for i64impl<T> VaArgSafe for *mut Timpl VaArgSafe for i32impl VaArgSafe for f64