Type Alias c_ssize_t

type c_ssize_t = isize

Equivalent to C's ssize_t (on POSIX) or SSIZE_T (on Windows) type.

This type is currently always isize, however in the future there may be platforms where this is not the case.