Type Alias c_uchar
type c_uchar = u8
Equivalent to C's unsigned char type.
This type will always be u8, but is included for completeness. It is defined as being an unsigned integer the same size as a C char.
c_uchartype c_uchar = u8
Equivalent to C's unsigned char type.
This type will always be u8, but is included for completeness. It is defined as being an unsigned integer the same size as a C char.