Macro field_of

macro field_of($Container:ty, $($fields:expr)+ $(,)?) {
    ...
}

Expands to the field representing type of the given field.

The container type may be a tuple, struct, union or enum. In the case of an enum, the variant must also be specified. Only a single field is supported.