Trait Field

unsafe trait Field: Send + Sync + Copy

Type representing a field of a struct, union, enum variant or tuple.

Safety

Given a valid value of type Self::Base, there exists a valid value of type Self::Type at byte offset OFFSET

Associated Types

type Base

The type of the base where this field exists in.

type Type

The type of the field.