Struct DebugSet

struct DebugSet<'a, 'b: 'a> { ... }

A struct to help with fmt::Debug implementations.

This is useful when you wish to output a formatted set of items as a part of your Debug::fmt implementation.

This can be constructed by the Formatter::debug_set method.

Examples

use std::fmt;

struct Foo(Vec<i32>);

impl fmt::Debug for Foo {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_set().entries(self.0.iter()).finish()
    }
}

assert_eq!(
    format!("{:?}", Foo(vec![10, 11])),
    "{10, 11}",
);

Implementations

impl<'a, 'b: 'a> DebugSet<'a, 'b>

fn entry(self: &mut Self, entry: &dyn Debug) -> &mut Self

Adds a new entry to the set output.

Examples

use std::fmt;

struct Foo(Vec<i32>, Vec<u32>);

impl fmt::Debug for Foo {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_set()
           .entry(&self.0) // Adds the first "entry".
           .entry(&self.1) // Adds the second "entry".
           .finish()
    }
}

assert_eq!(
    format!("{:?}", Foo(vec![10, 11], vec![12, 13])),
    "{[10, 11], [12, 13]}",
);
fn entry_with<F>(self: &mut Self, entry_fmt: F) -> &mut Self
where
    F: FnOnce(&mut Formatter<'_>) -> Result

Adds a new entry to the set output.

This method is equivalent to DebugSet::entry, but formats the entry using a provided closure rather than by calling Debug::fmt.

fn entries<D, I>(self: &mut Self, entries: I) -> &mut Self
where
    D: Debug,
    I: IntoIterator<Item = D>

Adds the contents of an iterator of entries to the set output.

Examples

use std::fmt;

struct Foo(Vec<i32>, Vec<u32>);

impl fmt::Debug for Foo {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_set()
           .entries(self.0.iter()) // Adds the first "entry".
           .entries(self.1.iter()) // Adds the second "entry".
           .finish()
    }
}

assert_eq!(
    format!("{:?}", Foo(vec![10, 11], vec![12, 13])),
    "{10, 11, 12, 13}",
);
fn finish_non_exhaustive(self: &mut Self) -> Result

Marks the set as non-exhaustive, indicating to the reader that there are some other elements that are not shown in the debug representation.

Examples

use std::fmt;

struct Foo(Vec<i32>);

impl fmt::Debug for Foo {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        // Print at most two elements, abbreviate the rest
        let mut f = fmt.debug_set();
        let mut f = f.entries(self.0.iter().take(2));
        if self.0.len() > 2 {
            f.finish_non_exhaustive()
        } else {
            f.finish()
        }
    }
}

assert_eq!(
    format!("{:?}", Foo(vec![1, 2, 3, 4])),
    "{1, 2, ..}",
);
fn finish(self: &mut Self) -> Result

Finishes output and returns any error encountered.

Examples

use std::fmt;

struct Foo(Vec<i32>);

impl fmt::Debug for Foo {
    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
        fmt.debug_set()
           .entries(self.0.iter())
           .finish() // Ends the set formatting.
    }
}

assert_eq!(
    format!("{:?}", Foo(vec![10, 11])),
    "{10, 11}",
);

impl<'a, 'b> Freeze for DebugSet<'a, 'b>

impl<'a, 'b> RefUnwindSafe for DebugSet<'a, 'b>

impl<'a, 'b> Send for DebugSet<'a, 'b>

impl<'a, 'b> Sync for DebugSet<'a, 'b>

impl<'a, 'b> Unpin for DebugSet<'a, 'b>

impl<'a, 'b> UnsafeUnpin for DebugSet<'a, 'b>

impl<'a, 'b> UnwindSafe for DebugSet<'a, 'b>

impl<T> Any for DebugSet<'a, 'b>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DebugSet<'a, 'b>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DebugSet<'a, 'b>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for DebugSet<'a, 'b>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DebugSet<'a, 'b>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DebugSet<'a, 'b>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DebugSet<'a, 'b>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>