Struct NumBuffer
struct NumBuffer<T: NumBufferTrait> { ... }
A buffer wrapper of which the internal size is based on the maximum number of digits the associated integer can have.
Implementations
impl<T: NumBufferTrait> NumBuffer<T>
const fn new() -> SelfInitializes internal buffer.
const fn capacity(self: &Self) -> usizeReturns the length of the internal buffer.
impl<T> Any for NumBuffer<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for NumBuffer<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for NumBuffer<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for NumBuffer<T>
impl<T> From for NumBuffer<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for NumBuffer<T>
impl<T> Send for NumBuffer<T>
impl<T> Sync for NumBuffer<T>
impl<T> Unpin for NumBuffer<T>
impl<T> UnsafeUnpin for NumBuffer<T>
impl<T> UnwindSafe for NumBuffer<T>
impl<T, U> Into for NumBuffer<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for NumBuffer<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for NumBuffer<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::fmt::Debug + NumBufferTrait> Debug for NumBuffer<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result