Struct Pending

struct Pending<T> { ... }

Creates a future which never resolves, representing a computation that never finishes.

This struct is created by [pending()]. See its documentation for more.

Implementations

impl<F> IntoFuture for Pending<T>

fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture

impl<T> Any for Pending<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Pending<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Pending<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Clone for Pending<T>

fn clone(self: &Self) -> Self

impl<T> CloneToUninit for Pending<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Debug for Pending<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Freeze for Pending<T>

impl<T> From for Pending<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Future for Pending<T>

fn poll(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<T>

impl<T> RefUnwindSafe for Pending<T>

impl<T> Send for Pending<T>

impl<T> Sync for Pending<T>

impl<T> Unpin for Pending<T>

impl<T> UnsafeUnpin for Pending<T>

impl<T> UnwindSafe for Pending<T>

impl<T, U> Into for Pending<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Pending<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Pending<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>