Function const_make_global

unsafe const fn const_make_global(ptr: *mut u8) -> *const u8

Convert the allocation this pointer points to into immutable global memory. The pointer must point to the beginning of a heap allocation. This operation only makes sense during compile time. At runtime, it does nothing.