Function type_of
const fn type_of(_id: TypeId) -> Type
Compute the type information of a concrete type. It can only be called at compile time, the backends do not implement it.
type_ofconst fn type_of(_id: TypeId) -> Type
Compute the type information of a concrete type. It can only be called at compile time, the backends do not implement it.