Function va_arg

unsafe const fn va_arg<T: VaArgSafe>(ap: &mut VaList<'_>) -> T

Loads an argument of type T from the va_list ap and increment the argument ap points to.

Safety

This function is only sound to call when:

Calling this function with an incompatible type, an invalid value, or when there are no more variable arguments, is unsound.