Function va_copy

const fn va_copy<'f>(src: &VaList<'f>) -> VaList<'f>

Duplicates a variable argument list. The returned list is initially at the same position as the one in src, but can be advanced independently.

Codegen backends should not have custom behavior for this intrinsic, they should always use this fallback implementation. This intrinsic does not map to the LLVM va_copy intrinsic.

This intrinsic exists only as a hook for Miri and constant evaluation, and is used to detect UB when a variable argument list is used incorrectly.