Function va_end
unsafe const fn va_end(ap: &mut VaList<'_>)
Destroy the variable argument list ap after initialization with va_start (part of the
desugaring of ...) or va_copy.
Code generation backends should not provide a custom implementation for this intrinsic. This
intrinsic does not map to the LLVM va_end intrinsic.
This function is a no-op on all current targets, but used as a hook for const evaluation to detect UB when a variable argument list is used incorrectly.
Safety
ap must not be used to access variable arguments after this call.