Function simd_carryless_mul

unsafe fn simd_carryless_mul<T>(a: T, b: T) -> T

Compute the carry-less product.

This is similar to long multiplication except that the carry is discarded.

This operation can be used to model multiplication in GF(2)[X], the polynomial ring over GF(2).

T must be a vector of integers.