Function simd_splat
unsafe const fn simd_splat<T, U>(value: U) -> T
Creates a vector where every lane has the provided value.
T must be a vector with element type U.
simd_splatunsafe const fn simd_splat<T, U>(value: U) -> T
Creates a vector where every lane has the provided value.
T must be a vector with element type U.