Struct Cycle

struct Cycle<I> { ... }

An iterator that repeats endlessly.

This struct is created by the cycle method on Iterator. See its documentation for more.

Implementations

impl<I> Freeze for Cycle<I>

impl<I> FusedIterator for Cycle<I>

impl<I> IntoIterator for Cycle<I>

fn into_iter(self: Self) -> I

impl<I> Iterator for Cycle<I>

fn next(self: &mut Self) -> Option<<I as Iterator>::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn try_fold<Acc, F, R>(self: &mut Self, acc: Acc, f: F) -> R
where
    F: FnMut(Acc, <Self as >::Item) -> R,
    R: Try<Output = Acc>
fn advance_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>

impl<I> RefUnwindSafe for Cycle<I>

impl<I> Send for Cycle<I>

impl<I> Sync for Cycle<I>

impl<I> Unpin for Cycle<I>

impl<I> UnsafeUnpin for Cycle<I>

impl<I> UnwindSafe for Cycle<I>

impl<I: $crate::clone::Clone> Clone for Cycle<I>

fn clone(self: &Self) -> Cycle<I>

impl<I: $crate::fmt::Debug> Debug for Cycle<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Cycle<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Cycle<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Cycle<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Cycle<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Cycle<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Cycle<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Cycle<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Cycle<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>