Struct Intersperse

struct Intersperse<I: Iterator> { ... }
where
    <I as >::Item: Clone

An iterator adapter that places a separator between all elements.

This struct is created by Iterator::intersperse. See its documentation for more information.

Implementations

impl<I> Freeze for Intersperse<I>

impl<I> FusedIterator for Intersperse<I>

impl<I> IntoIterator for Intersperse<I>

fn into_iter(self: Self) -> I

impl<I> Iterator for Intersperse<I>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn fold<B, F>(self: Self, init: B, f: F) -> B
where
    Self: Sized,
    F: FnMut(B, <Self as >::Item) -> B

impl<I> RefUnwindSafe for Intersperse<I>

impl<I> Send for Intersperse<I>

impl<I> Sync for Intersperse<I>

impl<I> Unpin for Intersperse<I>

impl<I> UnsafeUnpin for Intersperse<I>

impl<I> UnwindSafe for Intersperse<I>

impl<I: $crate::clone::Clone + Iterator> Clone for Intersperse<I>

fn clone(self: &Self) -> Intersperse<I>

impl<I: $crate::fmt::Debug + Iterator> Debug for Intersperse<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Intersperse<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Intersperse<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Intersperse<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Intersperse<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Intersperse<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Intersperse<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Intersperse<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Intersperse<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>