Struct MapWhile
struct MapWhile<I, P> { ... }
An iterator that only accepts elements while predicate returns Some(_).
This struct is created by the map_while method on Iterator. See its
documentation for more.
Implementations
impl<B, I: Iterator, P> Iterator for MapWhile<I, P>
fn next(self: &mut Self) -> Option<B>fn size_hint(self: &Self) -> (usize, Option<usize>)fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn fold<AAA, FFF>(self: Self, init: AAA, fold: FFF) -> AAA where FFF: FnMut(AAA, <Self as >::Item) -> AAA
impl<I> IntoIterator for MapWhile<I, P>
fn into_iter(self: Self) -> I
impl<I, P> Freeze for MapWhile<I, P>
impl<I, P> RefUnwindSafe for MapWhile<I, P>
impl<I, P> Send for MapWhile<I, P>
impl<I, P> Sync for MapWhile<I, P>
impl<I, P> Unpin for MapWhile<I, P>
impl<I, P> UnsafeUnpin for MapWhile<I, P>
impl<I, P> UnwindSafe for MapWhile<I, P>
impl<I: $crate::clone::Clone, P: $crate::clone::Clone> Clone for MapWhile<I, P>
fn clone(self: &Self) -> MapWhile<I, P>
impl<I: fmt::Debug, P> Debug for MapWhile<I, P>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for MapWhile<I, P>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MapWhile<I, P>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MapWhile<I, P>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MapWhile<I, P>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MapWhile<I, P>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for MapWhile<I, P>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MapWhile<I, P>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MapWhile<I, P>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>