Struct MapWindows
struct MapWindows<I: Iterator, F, N: usize> { ... }
An iterator over the mapped windows of another iterator.
This struct is created by the Iterator::map_windows. See its
documentation for more information.
Implementations
impl<I> IntoIterator for MapWindows<I, F, N>
fn into_iter(self: Self) -> I
impl<I, F, N: usize> Clone for MapWindows<I, F, N>
fn clone(self: &Self) -> Self
impl<I, F, N: usize> Freeze for MapWindows<I, F, N>
impl<I, F, N: usize> RefUnwindSafe for MapWindows<I, F, N>
impl<I, F, N: usize> Send for MapWindows<I, F, N>
impl<I, F, N: usize> Sync for MapWindows<I, F, N>
impl<I, F, N: usize> Unpin for MapWindows<I, F, N>
impl<I, F, N: usize> UnsafeUnpin for MapWindows<I, F, N>
impl<I, F, N: usize> UnwindSafe for MapWindows<I, F, N>
impl<I, F, R, N: usize> ExactSizeIterator for MapWindows<I, F, N>
impl<I, F, R, N: usize> FusedIterator for MapWindows<I, F, N>
impl<I, F, R, N: usize> Iterator for MapWindows<I, F, N>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<I: Iterator + fmt::Debug, F, N: usize> Debug for MapWindows<I, F, N>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for MapWindows<I, F, N>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MapWindows<I, F, N>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MapWindows<I, F, N>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MapWindows<I, F, N>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MapWindows<I, F, N>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for MapWindows<I, F, N>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MapWindows<I, F, N>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MapWindows<I, F, N>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>