Struct RepeatWith
struct RepeatWith<F> { ... }
An iterator that repeats elements of type A endlessly by
applying the provided closure F: FnMut() -> A.
This struct is created by the [repeat_with()] function.
See its documentation for more.
Implementations
impl<A, F: FnMut() -> A> FusedIterator for RepeatWith<F>
impl<A, F: FnMut() -> A> Iterator for RepeatWith<F>
fn next(self: &mut Self) -> Option<A>fn size_hint(self: &Self) -> (usize, Option<usize>)fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>
impl<A, F: FnMut() -> A> TrustedLen for RepeatWith<F>
impl<F> Debug for RepeatWith<F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<F> Freeze for RepeatWith<F>
impl<F> RefUnwindSafe for RepeatWith<F>
impl<F> Send for RepeatWith<F>
impl<F> Sync for RepeatWith<F>
impl<F> Unpin for RepeatWith<F>
impl<F> UnsafeUnpin for RepeatWith<F>
impl<F> UnwindSafe for RepeatWith<F>
impl<F: $crate::clone::Clone> Clone for RepeatWith<F>
fn clone(self: &Self) -> RepeatWith<F>
impl<F: $crate::marker::Copy> Copy for RepeatWith<F>
impl<I> IntoIterator for RepeatWith<F>
fn into_iter(self: Self) -> I
impl<T> Any for RepeatWith<F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RepeatWith<F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RepeatWith<F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for RepeatWith<F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for RepeatWith<F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for RepeatWith<F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RepeatWith<F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RepeatWith<F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>