Struct Scan

struct Scan<I, St, F> { ... }

An iterator to maintain state while iterating another iterator.

This struct is created by the scan method on Iterator. See its documentation for more.

Implementations

impl<B, I, St, F> Iterator for Scan<I, St, F>

fn next(self: &mut Self) -> Option<B>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R
where
    Self: Sized,
    Fold: FnMut(Acc, <Self as >::Item) -> R,
    R: Try<Output = Acc>
fn fold<AAA, FFF>(self: Self, init: AAA, fold: FFF) -> AAA
where
    FFF: FnMut(AAA, <Self as >::Item) -> AAA

impl<I> IntoIterator for Scan<I, St, F>

fn into_iter(self: Self) -> I

impl<I, St, F> Freeze for Scan<I, St, F>

impl<I, St, F> RefUnwindSafe for Scan<I, St, F>

impl<I, St, F> Send for Scan<I, St, F>

impl<I, St, F> Sync for Scan<I, St, F>

impl<I, St, F> Unpin for Scan<I, St, F>

impl<I, St, F> UnsafeUnpin for Scan<I, St, F>

impl<I, St, F> UnwindSafe for Scan<I, St, F>

impl<I: $crate::clone::Clone, St: $crate::clone::Clone, F: $crate::clone::Clone> Clone for Scan<I, St, F>

fn clone(self: &Self) -> Scan<I, St, F>

impl<I: fmt::Debug, St: fmt::Debug, F> Debug for Scan<I, St, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Scan<I, St, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Scan<I, St, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Scan<I, St, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Scan<I, St, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Scan<I, St, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Scan<I, St, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Scan<I, St, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Scan<I, St, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>