Struct Successors
struct Successors<T, F> { ... }
An iterator which, starting from an initial item, computes each successive item from the preceding one.
This struct is created by the iter::successors() function.
See its documentation for more.
Implementations
impl<I> IntoIterator for Successors<T, F>
fn into_iter(self: Self) -> I
impl<T> Any for Successors<T, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Successors<T, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Successors<T, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Successors<T, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Successors<T, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, F> Freeze for Successors<T, F>
impl<T, F> FusedIterator for Successors<T, F>
impl<T, F> Iterator for Successors<T, F>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<T, F> RefUnwindSafe for Successors<T, F>
impl<T, F> Send for Successors<T, F>
impl<T, F> Sync for Successors<T, F>
impl<T, F> Unpin for Successors<T, F>
impl<T, F> UnsafeUnpin for Successors<T, F>
impl<T, F> UnwindSafe for Successors<T, F>
impl<T, U> Into for Successors<T, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Successors<T, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Successors<T, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone, F: $crate::clone::Clone> Clone for Successors<T, F>
fn clone(self: &Self) -> Successors<T, F>
impl<T: fmt::Debug, F> Debug for Successors<T, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result