Struct TakeWhile

struct TakeWhile<I, P> { ... }

An iterator that only accepts elements while predicate returns true.

This struct is created by the take_while method on Iterator. See its documentation for more.

Implementations

impl<I> IntoIterator for TakeWhile<I, P>

fn into_iter(self: Self) -> I

impl<I, P> Freeze for TakeWhile<I, P>

impl<I, P> FusedIterator for TakeWhile<I, P>

impl<I, P> RefUnwindSafe for TakeWhile<I, P>

impl<I, P> Send for TakeWhile<I, P>

impl<I, P> Sync for TakeWhile<I, P>

impl<I, P> Unpin for TakeWhile<I, P>

impl<I, P> UnsafeUnpin for TakeWhile<I, P>

impl<I, P> UnwindSafe for TakeWhile<I, P>

impl<I: $crate::clone::Clone, P: $crate::clone::Clone> Clone for TakeWhile<I, P>

fn clone(self: &Self) -> TakeWhile<I, P>

impl<I: Iterator, P> Iterator for TakeWhile<I, P>

fn next(self: &mut Self) -> Option<<I as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R
where
    Self: Sized,
    Fold: FnMut(Acc, <Self as >::Item) -> R,
    R: Try<Output = Acc>
fn fold<AAA, FFF>(self: Self, init: AAA, fold: FFF) -> AAA
where
    FFF: FnMut(AAA, <Self as >::Item) -> AAA

impl<I: fmt::Debug, P> Debug for TakeWhile<I, P>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for TakeWhile<I, P>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TakeWhile<I, P>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TakeWhile<I, P>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TakeWhile<I, P>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TakeWhile<I, P>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for TakeWhile<I, P>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TakeWhile<I, P>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TakeWhile<I, P>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>