Type Alias NonZeroI16
type NonZeroI16 = NonZero<i16>
An i16 that is known not to equal zero.
This enables some memory layout optimization.
For example, Option<NonZeroI16> is the same size as i16:
assert_eq!;
Layout
NonZeroI16 is guaranteed to have the same layout and bit validity as i16
with the exception that 0 is not a valid instance.
Option<NonZeroI16> is guaranteed to be compatible with i16,
including in FFI.
Thanks to the null pointer optimization,
NonZeroI16 and Option<NonZeroI16>
are guaranteed to have the same size and alignment:
use NonZeroI16;
assert_eq!;
assert_eq!;
Compile-time creation
Since both [Option::unwrap()] and [Option::expect()] are const, it is possible to
define a new
NonZeroI16
at compile time via:
use NonZeroI16;
const TEN: NonZeroI16 = new.expect;