Type Alias NonZeroU64

type NonZeroU64 = NonZero<u64>

A u64 that is known not to equal zero.

This enables some memory layout optimization. For example, Option<NonZeroU64> is the same size as u64:

assert_eq!(size_of::<Option<core::num::NonZeroU64>>(), size_of::<u64>());

Layout

NonZeroU64 is guaranteed to have the same layout and bit validity as u64 with the exception that 0 is not a valid instance. Option<NonZeroU64> is guaranteed to be compatible with u64, including in FFI.

Thanks to the null pointer optimization, NonZeroU64 and Option<NonZeroU64> are guaranteed to have the same size and alignment:

use std::num::NonZeroU64;

assert_eq!(size_of::<NonZeroU64>(), size_of::<Option<NonZeroU64>>());
assert_eq!(align_of::<NonZeroU64>(), align_of::<Option<NonZeroU64>>());

Compile-time creation

Since both [Option::unwrap()] and [Option::expect()] are const, it is possible to define a new NonZeroU64 at compile time via:

use std::num::NonZeroU64;

const TEN: NonZeroU64 = NonZeroU64::new(10).expect("ten is non-zero");