Struct Yeet

struct Yeet<T>(23674)

Implement FromResidual<Yeet<T>> on your type to enable do yeet expr syntax in functions returning your type.

Implementations

impl<T> Any for Yeet<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Yeet<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Yeet<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Freeze for Yeet<T>

impl<T> From for Yeet<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for Yeet<T>

impl<T> Send for Yeet<T>

impl<T> Sync for Yeet<T>

impl<T> Unpin for Yeet<T>

impl<T> UnsafeUnpin for Yeet<T>

impl<T> UnwindSafe for Yeet<T>

impl<T, U> Into for Yeet<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Yeet<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Yeet<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::fmt::Debug> Debug for Yeet<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result