Trait AsyncFn
trait AsyncFn<Args: Tuple>: AsyncFnMut<Args>
An async-aware version of the Fn trait.
All async fn and functions returning futures implement this trait.
Required Methods
extern Other("\"rust-call\"") fn async_call(self: &Self, args: Args) -> <Self as >::CallRefFuture<'_>Call the
AsyncFn, returning a future which may borrow from the called closure.
Implementors
impl<A: Tuple, F> AsyncFn for &F