Trait AsyncFnMut

trait AsyncFnMut<Args: Tuple>: AsyncFnOnce<Args>

An async-aware version of the FnMut trait.

All async fn and functions returning futures implement this trait.

Associated Types

type CallRefFuture: TraitBound { trait_: Path { path: "Future", id: Id(215), args: Some(AngleBracketed { args: [], constraints: [AssocItemConstraint { name: "Output", args: None, binding: Equality(Type(QualifiedPath { name: "Output", args: None, self_type: Generic("Self"), trait_: Some(Path { path: "", id: Id(30), args: None }) })) }] }) }, generic_params: [], modifier: None }

Future returned by AsyncFnMut::async_call_mut and AsyncFn::async_call.

Required Methods

extern Other("\"rust-call\"") fn async_call_mut(self: &mut Self, args: Args) -> <Self as >::CallRefFuture<'_>

Call the AsyncFnMut, returning a future which may borrow from the called closure.

Implementors