Struct AssertUnwindSafe
struct AssertUnwindSafe<T>(28356)
A simple wrapper around a type to assert that it is unwind safe.
When using catch_unwind it may be the case that some of the closed over
variables are not unwind safe. For example if &mut T is captured the
compiler will generate a warning indicating that it is not unwind safe. It
might not be the case, however, that this is actually a problem due to the
specific usage of catch_unwind if unwind safety is specifically taken into
account. This wrapper struct is useful for a quick and lightweight
annotation that a variable is indeed unwind safe.
Examples
One way to use AssertUnwindSafe is to assert that the entire closure
itself is unwind safe, bypassing all checks for all variables:
use ;
let mut variable = 4;
// This code will not compile because the closure captures `&mut variable`
// which is not considered unwind safe by default.
// panic::catch_unwind(|| {
// variable += 3;
// });
// This, however, will compile due to the `AssertUnwindSafe` wrapper
let result = catch_unwind;
// ...
Wrapping the entire closure amounts to a blanket assertion that all captured variables are unwind safe. This has the downside that if new captures are added in the future, they will also be considered unwind safe. Therefore, you may prefer to just wrap individual captures, as shown below. This is more annotation, but it ensures that if a new capture is added which is not unwind safe, you will get a compilation error at that time, which will allow you to consider whether that new capture in fact represent a bug or not.
use ;
let mut variable = 4;
let other_capture = 3;
let result = ;
// ...
Implementations
impl<F> IntoFuture for AssertUnwindSafe<T>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<F: Future> Future for AssertUnwindSafe<F>
fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>
impl<I> IntoAsyncIterator for AssertUnwindSafe<T>
fn into_async_iter(self: Self) -> <I as IntoAsyncIterator>::IntoAsyncIter
impl<P, T> Receiver for AssertUnwindSafe<T>
impl<R, F: FnOnce() -> R> FnOnce for AssertUnwindSafe<F>
extern Other("\"rust-call\"") fn call_once(self: Self, _args: ()) -> R
impl<S: AsyncIterator> AsyncIterator for AssertUnwindSafe<S>
fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<<S as >::Item>>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<T> Any for AssertUnwindSafe<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for AssertUnwindSafe<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for AssertUnwindSafe<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Deref for AssertUnwindSafe<T>
fn deref(self: &Self) -> &T
impl<T> DerefMut for AssertUnwindSafe<T>
fn deref_mut(self: &mut Self) -> &mut T
impl<T> Freeze for AssertUnwindSafe<T>
impl<T> From for AssertUnwindSafe<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for AssertUnwindSafe<T>
impl<T> Send for AssertUnwindSafe<T>
impl<T> Sync for AssertUnwindSafe<T>
impl<T> Unpin for AssertUnwindSafe<T>
impl<T> UnsafeUnpin for AssertUnwindSafe<T>
impl<T> UnwindSafe for AssertUnwindSafe<T>
impl<T, U> Into for AssertUnwindSafe<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for AssertUnwindSafe<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for AssertUnwindSafe<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: Default> Default for AssertUnwindSafe<T>
fn default() -> Self
impl<T: fmt::Debug> Debug for AssertUnwindSafe<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result