Trait AsyncFnOnce
trait AsyncFnOnce<Args: Tuple>
An async-aware version of the FnOnce trait.
All async fn and functions returning futures implement this trait.
Associated Types
type CallOnceFuture: TraitBound { trait_: Path { path: "Future", id: Id(215), args: Some(AngleBracketed { args: [], constraints: [AssocItemConstraint { name: "Output", args: None, binding: Equality(Type(QualifiedPath { name: "Output", args: None, self_type: Generic("Self"), trait_: Some(Path { path: "", id: Id(30), args: None }) })) }] }) }, generic_params: [], modifier: None }Future returned by
AsyncFnOnce::async_call_once.type OutputOutput type of the called closure's future.
Required Methods
extern Other("\"rust-call\"") fn async_call_once(self: Self, args: Args) -> <Self as >::CallOnceFutureCall the
AsyncFnOnce, returning a future which may move out of the called closure.
Implementors
impl<'a, A: Tuple, F> AsyncFnOnce for &'a mut Fimpl<'a, A: Tuple, F> AsyncFnOnce for &'a F