Struct RangeFromIter

struct RangeFromIter<A> { ... }

By-value RangeFrom iterator.

Implementations

impl<A: Step> RangeFromIter<A>

fn remainder(self: Self) -> RangeFrom<A>

Returns the remainder of the range being iterated over.

impl<A> Freeze for RangeFromIter<A>

impl<A> RefUnwindSafe for RangeFromIter<A>

impl<A> Send for RangeFromIter<A>

impl<A> Sync for RangeFromIter<A>

impl<A> Unpin for RangeFromIter<A>

impl<A> UnsafeUnpin for RangeFromIter<A>

impl<A> UnwindSafe for RangeFromIter<A>

impl<A: $crate::clone::Clone> Clone for RangeFromIter<A>

fn clone(self: &Self) -> RangeFromIter<A>

impl<A: $crate::fmt::Debug> Debug for RangeFromIter<A>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<A: Step> FusedIterator for RangeFromIter<A>

impl<A: Step> Iterator for RangeFromIter<A>

fn next(self: &mut Self) -> Option<A>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn nth(self: &mut Self, n: usize) -> Option<A>

impl<A: TrustedStep> TrustedLen for RangeFromIter<A>

impl<I> IntoIterator for RangeFromIter<A>

fn into_iter(self: Self) -> I

impl<T> Any for RangeFromIter<A>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for RangeFromIter<A>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for RangeFromIter<A>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for RangeFromIter<A>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for RangeFromIter<A>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for RangeFromIter<A>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for RangeFromIter<A>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for RangeFromIter<A>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>