Function from_mut
const fn from_mut<T>(s: &mut T) -> &mut [T]
Converts a reference to T into a slice of length 1 (without copying).
from_mutconst fn from_mut<T>(s: &mut T) -> &mut [T]
Converts a reference to T into a slice of length 1 (without copying).