Struct ArrayWindows

struct ArrayWindows<'a, T: 'a, N: usize> { ... }

A windowed iterator over a slice in overlapping chunks (N elements at a time), starting at the beginning of the slice

This struct is created by the array_windows method on slices.

Example

let slice = [0, 1, 2, 3];
let mut iter = slice.array_windows::<2>();
assert_eq!(iter.next(), Some(&[0, 1]));
assert_eq!(iter.next(), Some(&[1, 2]));
assert_eq!(iter.next(), Some(&[2, 3]));
assert_eq!(iter.next(), None);

Implementations

impl<'a, T, N: usize> DoubleEndedIterator for ArrayWindows<'a, T, N>

fn next_back(self: &mut Self) -> Option<&'a [T; N]>
fn nth_back(self: &mut Self, n: usize) -> Option<&'a [T; N]>

impl<'a, T, N: usize> Freeze for ArrayWindows<'a, T, N>

impl<'a, T, N: usize> Iterator for ArrayWindows<'a, T, N>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn count(self: Self) -> usize
fn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>
fn last(self: Self) -> Option<<Self as >::Item>

impl<'a, T, N: usize> RefUnwindSafe for ArrayWindows<'a, T, N>

impl<'a, T, N: usize> Send for ArrayWindows<'a, T, N>

impl<'a, T, N: usize> Sync for ArrayWindows<'a, T, N>

impl<'a, T, N: usize> Unpin for ArrayWindows<'a, T, N>

impl<'a, T, N: usize> UnsafeUnpin for ArrayWindows<'a, T, N>

impl<'a, T, N: usize> UnwindSafe for ArrayWindows<'a, T, N>

impl<'a, T: $crate::fmt::Debug + 'a, N: usize> Debug for ArrayWindows<'a, T, N>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<I> IntoIterator for ArrayWindows<'a, T, N>

fn into_iter(self: Self) -> I

impl<T> Any for ArrayWindows<'a, T, N>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ArrayWindows<'a, T, N>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ArrayWindows<'a, T, N>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ArrayWindows<'a, T, N>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ArrayWindows<'a, T, N>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, N: usize> Clone for ArrayWindows<'_, T, N>

fn clone(self: &Self) -> Self

impl<T, N: usize> ExactSizeIterator for ArrayWindows<'_, T, N>

fn is_empty(self: &Self) -> bool

impl<T, N: usize> FusedIterator for ArrayWindows<'_, T, N>

impl<T, N: usize> TrustedLen for ArrayWindows<'_, T, N>

impl<T, U> Into for ArrayWindows<'a, T, N>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ArrayWindows<'a, T, N>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ArrayWindows<'a, T, N>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>