Struct EscapeAscii

struct EscapeAscii<'a> { ... }

An iterator over the escaped version of a byte slice.

This struct is created by the slice::escape_ascii method. See its documentation for more information.

Implementations

impl<'a> Clone for EscapeAscii<'a>

fn clone(self: &Self) -> EscapeAscii<'a>

impl<'a> Debug for EscapeAscii<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Display for EscapeAscii<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> DoubleEndedIterator for EscapeAscii<'a>

fn next_back(self: &mut Self) -> Option<u8>

impl<'a> Freeze for EscapeAscii<'a>

impl<'a> FusedIterator for EscapeAscii<'a>

impl<'a> Iterator for EscapeAscii<'a>

fn next(self: &mut Self) -> Option<u8>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R
where
    Fold: FnMut(Acc, <Self as >::Item) -> R,
    R: Try<Output = Acc>
fn fold<Acc, Fold>(self: Self, init: Acc, fold: Fold) -> Acc
where
    Fold: FnMut(Acc, <Self as >::Item) -> Acc
fn last(self: Self) -> Option<u8>

impl<'a> RefUnwindSafe for EscapeAscii<'a>

impl<'a> Send for EscapeAscii<'a>

impl<'a> Sync for EscapeAscii<'a>

impl<'a> Unpin for EscapeAscii<'a>

impl<'a> UnsafeUnpin for EscapeAscii<'a>

impl<'a> UnwindSafe for EscapeAscii<'a>

impl<I> IntoIterator for EscapeAscii<'a>

fn into_iter(self: Self) -> I

impl<T> Any for EscapeAscii<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for EscapeAscii<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for EscapeAscii<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for EscapeAscii<'a>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for EscapeAscii<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for EscapeAscii<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for EscapeAscii<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for EscapeAscii<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>