Struct RChunksExact

struct RChunksExact<'a, T: 'a> { ... }

An iterator over a slice in (non-overlapping) chunks (chunk_size elements at a time), starting at the end of the slice.

When the slice len is not evenly divided by the chunk size, the last up to chunk_size-1 elements will be omitted but can be retrieved from the remainder function from the iterator.

This struct is created by the rchunks_exact method on slices.

Example

let slice = ['l', 'o', 'r', 'e', 'm'];
let mut iter = slice.rchunks_exact(2);
assert_eq!(iter.next(), Some(&['e', 'm'][..]));
assert_eq!(iter.next(), Some(&['o', 'r'][..]));
assert_eq!(iter.next(), None);

Implementations

impl<'a, T> RChunksExact<'a, T>

const fn remainder(self: &Self) -> &'a [T]

Returns the remainder of the original slice that is not going to be returned by the iterator. The returned slice has at most chunk_size-1 elements.

Example

let slice = ['l', 'o', 'r', 'e', 'm'];
let mut iter = slice.rchunks_exact(2);
assert_eq!(iter.remainder(), &['l'][..]);
assert_eq!(iter.next(), Some(&['e', 'm'][..]));
assert_eq!(iter.remainder(), &['l'][..]);
assert_eq!(iter.next(), Some(&['o', 'r'][..]));
assert_eq!(iter.remainder(), &['l'][..]);
assert_eq!(iter.next(), None);
assert_eq!(iter.remainder(), &['l'][..]);

impl<'a, T> Clone for RChunksExact<'a, T>

fn clone(self: &Self) -> RChunksExact<'a, T>

impl<'a, T> DoubleEndedIterator for RChunksExact<'a, T>

fn next_back(self: &mut Self) -> Option<&'a [T]>
fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>

impl<'a, T> ExactSizeIterator for RChunksExact<'a, T>

fn is_empty(self: &Self) -> bool

impl<'a, T> Freeze for RChunksExact<'a, T>

impl<'a, T> Iterator for RChunksExact<'a, T>

fn next(self: &mut Self) -> Option<&'a [T]>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn count(self: Self) -> usize
fn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>
fn last(self: Self) -> Option<<Self as >::Item>

impl<'a, T> RefUnwindSafe for RChunksExact<'a, T>

impl<'a, T> Send for RChunksExact<'a, T>

impl<'a, T> Sync for RChunksExact<'a, T>

impl<'a, T> Unpin for RChunksExact<'a, T>

impl<'a, T> UnsafeUnpin for RChunksExact<'a, T>

impl<'a, T> UnwindSafe for RChunksExact<'a, T>

impl<'a, T: $crate::fmt::Debug + 'a> Debug for RChunksExact<'a, T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<I> IntoIterator for RChunksExact<'a, T>

fn into_iter(self: Self) -> I

impl<T> Any for RChunksExact<'a, T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for RChunksExact<'a, T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for RChunksExact<'a, T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for RChunksExact<'a, T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for RChunksExact<'a, T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> FusedIterator for RChunksExact<'_, T>

impl<T> TrustedLen for RChunksExact<'_, T>

impl<T, U> Into for RChunksExact<'a, T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for RChunksExact<'a, T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for RChunksExact<'a, T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>