Struct RSplitN
struct RSplitN<'a, T: 'a, P> { ... }
where
P: FnMut(&T) -> bool
An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.
This struct is created by the rsplitn method on slices.
Example
let slice = ;
let mut iter = slice.rsplitn;
assert_eq!;
assert_eq!;
assert_eq!;
Implementations
impl<'a, T, P> Freeze for RSplitN<'a, T, P>
impl<'a, T, P> FusedIterator for RSplitN<'a, T, P>
impl<'a, T, P> Iterator for RSplitN<'a, T, P>
fn next(self: &mut Self) -> Option<&'a [T]>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'a, T, P> RefUnwindSafe for RSplitN<'a, T, P>
impl<'a, T, P> Send for RSplitN<'a, T, P>
impl<'a, T, P> Sync for RSplitN<'a, T, P>
impl<'a, T, P> Unpin for RSplitN<'a, T, P>
impl<'a, T, P> UnsafeUnpin for RSplitN<'a, T, P>
impl<'a, T, P> UnwindSafe for RSplitN<'a, T, P>
impl<I> IntoIterator for RSplitN<'a, T, P>
fn into_iter(self: Self) -> I
impl<T> Any for RSplitN<'a, T, P>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RSplitN<'a, T, P>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RSplitN<'a, T, P>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for RSplitN<'a, T, P>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for RSplitN<'a, T, P>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RSplitN<'a, T, P>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RSplitN<'a, T, P>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: fmt::Debug, P> Debug for RSplitN<'_, T, P>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result