Struct Windows
struct Windows<'a, T: 'a> { ... }
An iterator over overlapping subslices of length size.
This struct is created by the windows method on slices.
Example
let slice = ;
let mut iter = slice.windows;
assert_eq!;
assert_eq!;
assert_eq!;
assert_eq!;
Implementations
impl<'a, T> DoubleEndedIterator for Windows<'a, T>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<'a, T> Freeze for Windows<'a, T>
impl<'a, T> Iterator for Windows<'a, T>
fn next(self: &mut Self) -> Option<&'a [T]>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>
impl<'a, T> RefUnwindSafe for Windows<'a, T>
impl<'a, T> Send for Windows<'a, T>
impl<'a, T> Sync for Windows<'a, T>
impl<'a, T> Unpin for Windows<'a, T>
impl<'a, T> UnsafeUnpin for Windows<'a, T>
impl<'a, T> UnwindSafe for Windows<'a, T>
impl<'a, T: $crate::fmt::Debug + 'a> Debug for Windows<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I> IntoIterator for Windows<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for Windows<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Windows<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Windows<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Clone for Windows<'_, T>
fn clone(self: &Self) -> Self
impl<T> CloneToUninit for Windows<'a, T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ExactSizeIterator for Windows<'_, T>
impl<T> From for Windows<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for Windows<'_, T>
impl<T> TrustedLen for Windows<'_, T>
impl<T, U> Into for Windows<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Windows<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Windows<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>