Function from_utf8_unchecked
unsafe const fn from_utf8_unchecked(v: &[u8]) -> &str
Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8.
This is an alias to str::from_utf8_unchecked.
See the safe version, from_utf8, for more information.
Safety
The bytes passed in must be valid UTF-8.
Examples
Basic usage:
use str;
// some bytes, in a vector
let sparkle_heart = vec!;
let sparkle_heart = unsafe ;
assert_eq!;