Function utf8_char_width
const fn utf8_char_width(b: u8) -> usize
Given a first byte, determines how many bytes are in this UTF-8 character.
utf8_char_widthconst fn utf8_char_width(b: u8) -> usize
Given a first byte, determines how many bytes are in this UTF-8 character.