Struct Utf8Chunks
struct Utf8Chunks<'a> { ... }
An iterator used to decode a slice of mostly UTF-8 bytes to string slices
([&str]) and byte slices (&[u8]).
This struct is created by the utf8_chunks method on bytes slices.
If you want a simple conversion from UTF-8 byte slices to string slices,
from_utf8 is easier to use.
See the Utf8Chunk type for documentation of the items yielded by this iterator.
Examples
This can be used to create functionality similar to
String::from_utf8_lossy without allocating heap memory:
Implementations
impl Debug for Utf8Chunks<'_>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl FusedIterator for Utf8Chunks<'_>
impl<'a> Clone for Utf8Chunks<'a>
fn clone(self: &Self) -> Utf8Chunks<'a>
impl<'a> Freeze for Utf8Chunks<'a>
impl<'a> Iterator for Utf8Chunks<'a>
fn next(self: &mut Self) -> Option<Utf8Chunk<'a>>
impl<'a> RefUnwindSafe for Utf8Chunks<'a>
impl<'a> Send for Utf8Chunks<'a>
impl<'a> Sync for Utf8Chunks<'a>
impl<'a> Unpin for Utf8Chunks<'a>
impl<'a> UnsafeUnpin for Utf8Chunks<'a>
impl<'a> UnwindSafe for Utf8Chunks<'a>
impl<I> IntoIterator for Utf8Chunks<'a>
fn into_iter(self: Self) -> I
impl<T> Any for Utf8Chunks<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Utf8Chunks<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Utf8Chunks<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Utf8Chunks<'a>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Utf8Chunks<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Utf8Chunks<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Utf8Chunks<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Utf8Chunks<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>