Crate tinyboot

Crate tinyboot 

Platform-agnostic bootloader core.

Implements the boot state machine, protocol dispatcher, and app validation. Platform-specific behaviour is injected via the traits in traits::boot.

Re-exports

pub use crate::core::Core;

Modules

app
App-side tinyboot client (poll, confirm, command handling). App-side tinyboot client.
core
Boot state machine and entry point.
protocol
Protocol frame dispatcher.
traits
Platform abstraction traits.