Trait AtomicPrimitive

unsafe trait AtomicPrimitive: Sized + Copy + private::Sealed

A marker trait for primitive types which can be modified atomically.

This is an implementation detail for [Atomic]<T> which may disappear or be replaced at any time.

Associated Types

type Storage: TraitBound { trait_: Path { path: "Sized", id: Id(12), args: None }, generic_params: [], modifier: None }

Temporary implementation detail.

Implementors