Struct RawWakerVTable

struct RawWakerVTable { ... }

A virtual function pointer table (vtable) that specifies the behavior of a RawWaker.

The pointer passed to all functions inside the vtable is the data pointer from the enclosing RawWaker object.

The functions inside this struct are only intended to be called on the data pointer of a properly constructed RawWaker object from inside the RawWaker implementation. Calling one of the contained functions using any other data pointer will cause undefined behavior.

Note that while this type implements PartialEq, comparing function pointers, and hence comparing structs like this that contain function pointers, is unreliable: pointers to the same function can compare inequal (because functions are duplicated in multiple codegen units), and pointers to different functions can compare equal (since identical functions can be deduplicated within a codegen unit).

Thread safety

If the RawWaker will be used to construct a Waker then these functions must all be thread-safe (even though RawWaker is ![Send] + ![Sync]). This is because Waker is [Send] + [Sync], and it may be moved to arbitrary threads or invoked by & reference. For example, this means that if the clone and drop functions manage a reference count, they must do so atomically.

However, if the RawWaker will be used to construct a LocalWaker instead, then these functions don't need to be thread safe. This means that ![Send] + ![Sync] data can be stored in the data pointer, and reference counting does not need any atomic synchronization. This is because LocalWaker is not thread safe itself, so it cannot be sent across threads.

Implementations

impl RawWakerVTable

const fn new(clone: unsafe fn(_: *const ()) -> RawWaker, wake: unsafe fn(_: *const ()), wake_by_ref: unsafe fn(_: *const ()), drop: unsafe fn(_: *const ())) -> Self

Creates a new RawWakerVTable from the provided clone, wake, wake_by_ref, and drop functions.

If the RawWaker will be used to construct a Waker then these functions must all be thread-safe (even though RawWaker is ![Send] + ![Sync]). This is because Waker is [Send] + [Sync], and it may be moved to arbitrary threads or invoked by & reference. For example, this means that if the clone and drop functions manage a reference count, they must do so atomically.

However, if the RawWaker will be used to construct a LocalWaker instead, then these functions don't need to be thread safe. This means that ![Send] + ![Sync] data can be stored in the data pointer, and reference counting does not need any atomic synchronization. This is because LocalWaker is not thread safe itself, so it cannot be sent across threads.

clone

This function will be called when the RawWaker gets cloned, e.g. when the Waker/LocalWaker in which the RawWaker is stored gets cloned.

The implementation of this function must retain all resources that are required for this additional instance of a RawWaker and associated task. Calling wake on the resulting RawWaker should result in a wakeup of the same task that would have been awoken by the original RawWaker.

wake

This function will be called when wake is called on the Waker. It must wake up the task associated with this RawWaker.

The implementation of this function must make sure to release any resources that are associated with this instance of a RawWaker and associated task.

wake_by_ref

This function will be called when wake_by_ref is called on the Waker. It must wake up the task associated with this RawWaker.

This function is similar to wake, but must not consume the provided data pointer.

drop

This function will be called when a Waker/LocalWaker gets dropped.

The implementation of this function must make sure to release any resources that are associated with this instance of a RawWaker and associated task.

impl Clone for RawWakerVTable

fn clone(self: &Self) -> RawWakerVTable

impl Copy for RawWakerVTable

impl Debug for RawWakerVTable

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for RawWakerVTable

impl PartialEq for RawWakerVTable

fn eq(self: &Self, other: &RawWakerVTable) -> bool

impl RefUnwindSafe for RawWakerVTable

impl Send for RawWakerVTable

impl StructuralPartialEq for RawWakerVTable

impl Sync for RawWakerVTable

impl Unpin for RawWakerVTable

impl UnsafeUnpin for RawWakerVTable

impl UnwindSafe for RawWakerVTable

impl<T> Any for RawWakerVTable

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for RawWakerVTable

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for RawWakerVTable

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for RawWakerVTable

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for RawWakerVTable

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for RawWakerVTable

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for RawWakerVTable

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for RawWakerVTable

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>