pub struct ContainerRestartRuleOnExitCodes {
pub operator: String,
pub values: Option<Vec<i32>>,
}Expand description
ContainerRestartRuleOnExitCodes describes the condition for handling an exited container based on its exit codes.
Fields
operator: StringRepresents the relationship between the container exit code(s) and the specified values. Possible values are: - In: the requirement is satisfied if the container exit code is in the set of specified values.
- NotIn: the requirement is satisfied if the container exit code is not in the set of specified values.
values: Option<Vec<i32>>Specifies the set of values to check for container exit codes. At most 255 elements are allowed.