pub struct NodeAllocatableResourceClaimStatus {
pub containers: Option<Vec<String>>,
pub resource_claim_name: String,
pub resources: BTreeMap<String, Quantity>,
}Expand description
NodeAllocatableResourceClaimStatus describes the status of node allocatable resources allocated via DRA.
Fields
containers: Option<Vec<String>>Containers lists the names of all containers in this pod that reference the claim.
resource_claim_name: StringResourceClaimName is the resource claim referenced by the pod that resulted in this node allocatable resource allocation.
resources: BTreeMap<String, Quantity>Resources is a map of the node-allocatable resource name to the aggregate quantity allocated to the claim.