Crate basic_stats

A lightweight library that provides some basic parametric and non-parametric statistics and hypothesis tests.

Some modules are gated by cargo features, as indicated in module documentation. The feature “all” includes all features.

Modules

bernoulli
Statistics related to the Bernoulli distribution. Gated by feature bernoulli.
core
Core sample statistics and common types.
error
Errors returned by functions in this library.
iter
Iterator functionality.
normal
Statistics related to the Normal distribution and Student’s t distribution, including the Student one-sample t-test and the Welch two-sample t-test (for samples from distributions that may have different variances).
wilcoxon
Statistics related to the Wilcoxon rank sum two-sample test, also known as the Mann-Whitney U test. Gated by feature wilcoxon.