pub unsafe fn __tile_cvtrowps2bf16h(src: __tile1024i, row: u32) -> __m512bh🔬This is a nightly-only experimental API. (
x86_amx_intrinsics #126622)Available on x86-64 and target feature
amx-avx512 and target feature avx10.2 only.Expand description
Moves a row from a tile register to a zmm register, converting the packed single-precision (32-bit)
floating-point elements to packed BF16 (16-bit) floating-point elements. The resulting
16-bit elements are placed in the high 16-bits within each 32-bit element of the returned vector.
The shape of the tile is specified in the struct of __tile1024i. The register of the tile is allocated by the compiler.