Struct DebugSet
struct DebugSet<'a, 'b: 'a> { ... }
A struct to help with fmt::Debug implementations.
This is useful when you wish to output a formatted set of items as a part
of your Debug::fmt implementation.
This can be constructed by the Formatter::debug_set method.
Examples
use fmt;
;
assert_eq!;
Implementations
impl<'a, 'b: 'a> DebugSet<'a, 'b>
fn entry(self: &mut Self, entry: &dyn Debug) -> &mut SelfAdds a new entry to the set output.
Examples
use fmt; ; assert_eq!;fn entry_with<F>(self: &mut Self, entry_fmt: F) -> &mut Self where F: FnOnce(&mut Formatter<'_>) -> ResultAdds a new entry to the set output.
This method is equivalent to
DebugSet::entry, but formats the entry using a provided closure rather than by callingDebug::fmt.fn entries<D, I>(self: &mut Self, entries: I) -> &mut Self where D: Debug, I: IntoIterator<Item = D>Adds the contents of an iterator of entries to the set output.
Examples
use fmt; ; assert_eq!;fn finish_non_exhaustive(self: &mut Self) -> ResultMarks the set as non-exhaustive, indicating to the reader that there are some other elements that are not shown in the debug representation.
Examples
use fmt; ; assert_eq!;fn finish(self: &mut Self) -> ResultFinishes output and returns any error encountered.
Examples
use fmt; ; assert_eq!;
impl<'a, 'b> Freeze for DebugSet<'a, 'b>
impl<'a, 'b> RefUnwindSafe for DebugSet<'a, 'b>
impl<'a, 'b> Send for DebugSet<'a, 'b>
impl<'a, 'b> Sync for DebugSet<'a, 'b>
impl<'a, 'b> Unpin for DebugSet<'a, 'b>
impl<'a, 'b> UnsafeUnpin for DebugSet<'a, 'b>
impl<'a, 'b> UnwindSafe for DebugSet<'a, 'b>
impl<T> Any for DebugSet<'a, 'b>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DebugSet<'a, 'b>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DebugSet<'a, 'b>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for DebugSet<'a, 'b>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for DebugSet<'a, 'b>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DebugSet<'a, 'b>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DebugSet<'a, 'b>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>