Macro join
macro join( $($fut:expr),+ $(,)? ) {
...
}
Polls multiple futures simultaneously, returning a tuple of all results once complete.
While join!(a, b).await is similar to (a.await, b.await),
join! polls both futures concurrently and is therefore more efficient.
Examples
use join;
async
async
# let _ = async ;
join! is variadic, so you can pass any number of futures:
use join;
async
async
async
# let _ = async ;