Struct Ready
struct Ready<T>(_)
A future that is immediately ready with a value.
This struct is created by [ready()]. See its
documentation for more.
Implementations
impl<T> Ready<T>
fn into_inner(self: Self) -> TConsumes the
Ready, returning the wrapped value.Panics
Will panic if this
Readywas already polled to completion.Examples
use future; let a = ready; assert_eq!;
impl<F> IntoFuture for Ready<T>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<T> Any for Ready<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Ready<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Ready<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Ready<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Freeze for Ready<T>
impl<T> From for Ready<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Future for Ready<T>
fn poll(self: Pin<&mut Self>, _cx: &mut Context<'_>) -> Poll<T>
impl<T> RefUnwindSafe for Ready<T>
impl<T> Send for Ready<T>
impl<T> Sync for Ready<T>
impl<T> Unpin for Ready<T>
impl<T> UnsafeUnpin for Ready<T>
impl<T> UnwindSafe for Ready<T>
impl<T, U> Into for Ready<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Ready<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Ready<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone> Clone for Ready<T>
fn clone(self: &Self) -> Ready<T>
impl<T: $crate::fmt::Debug> Debug for Ready<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result