Struct Cloned
struct Cloned<I> { ... }
An iterator that clones the elements of an underlying iterator.
This struct is created by the cloned method on Iterator. See its
documentation for more.
Implementations
impl<'a, I, T> DoubleEndedIterator for Cloned<I>
fn next_back(self: &mut Self) -> Option<T>fn try_rfold<B, F, R>(self: &mut Self, init: B, f: F) -> R where Self: Sized, F: FnMut(B, <Self as >::Item) -> R, R: Try<Output = B>fn rfold<Acc, F>(self: Self, init: Acc, f: F) -> Acc where F: FnMut(Acc, <Self as >::Item) -> Acc
impl<'a, I, T> ExactSizeIterator for Cloned<I>
fn len(self: &Self) -> usizefn is_empty(self: &Self) -> bool
impl<'a, I, T> FusedIterator for Cloned<I>
impl<'a, I, T> Iterator for Cloned<I>
fn next(self: &mut Self) -> Option<T>fn size_hint(self: &Self) -> (usize, Option<usize>)fn try_fold<B, F, R>(self: &mut Self, init: B, f: F) -> R where Self: Sized, F: FnMut(B, <Self as >::Item) -> R, R: Try<Output = B>fn fold<Acc, F>(self: Self, init: Acc, f: F) -> Acc where F: FnMut(Acc, <Self as >::Item) -> Acc
impl<'a, I, T> TrustedLen for Cloned<I>
impl<I> Freeze for Cloned<I>
impl<I> IntoIterator for Cloned<I>
fn into_iter(self: Self) -> I
impl<I> RefUnwindSafe for Cloned<I>
impl<I> Send for Cloned<I>
impl<I> Sync for Cloned<I>
impl<I> Unpin for Cloned<I>
impl<I> UnsafeUnpin for Cloned<I>
impl<I> UnwindSafe for Cloned<I>
impl<I: $crate::clone::Clone> Clone for Cloned<I>
fn clone(self: &Self) -> Cloned<I>
impl<I: $crate::fmt::Debug> Debug for Cloned<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I: Default> Default for Cloned<I>
fn default() -> SelfCreates a
Clonediterator from the default value ofI# use slice; # use Cloned; let iter: = Defaultdefault; assert_eq!;
impl<T> Any for Cloned<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Cloned<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Cloned<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Cloned<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Cloned<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Cloned<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Cloned<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Cloned<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>