Struct Filter
struct Filter<I, P> { ... }
An iterator that filters the elements of iter with predicate.
This struct is created by the filter method on Iterator. See its
documentation for more.
Implementations
impl<I> IntoIterator for Filter<I, P>
fn into_iter(self: Self) -> I
impl<I, P> Freeze for Filter<I, P>
impl<I, P> RefUnwindSafe for Filter<I, P>
impl<I, P> Send for Filter<I, P>
impl<I, P> Sync for Filter<I, P>
impl<I, P> Unpin for Filter<I, P>
impl<I, P> UnsafeUnpin for Filter<I, P>
impl<I, P> UnwindSafe for Filter<I, P>
impl<I: $crate::clone::Clone, P: $crate::clone::Clone> Clone for Filter<I, P>
fn clone(self: &Self) -> Filter<I, P>
impl<I: DoubleEndedIterator, P> DoubleEndedIterator for Filter<I, P>
fn next_back(self: &mut Self) -> Option<<I as >::Item>fn try_rfold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn rfold<Acc, Fold>(self: Self, init: Acc, fold: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Acc
impl<I: FusedIterator, P> FusedIterator for Filter<I, P>
impl<I: Iterator, P> Iterator for Filter<I, P>
fn next(self: &mut Self) -> Option<<I as >::Item>fn next_chunk<N: usize>(self: &mut Self) -> Result<[<Self as >::Item; N], IntoIter<<Self as >::Item, N>>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn fold<Acc, Fold>(self: Self, init: Acc, fold: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Acc
impl<I: fmt::Debug, P> Debug for Filter<I, P>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Filter<I, P>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Filter<I, P>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Filter<I, P>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Filter<I, P>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Filter<I, P>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Filter<I, P>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Filter<I, P>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Filter<I, P>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>