Struct FilterMap
struct FilterMap<I, F> { ... }
An iterator that uses f to both filter and map elements from iter.
This struct is created by the filter_map method on Iterator. See its
documentation for more.
Implementations
impl<B, I: DoubleEndedIterator, F> DoubleEndedIterator for FilterMap<I, F>
fn next_back(self: &mut Self) -> Option<B>fn try_rfold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn rfold<Acc, Fold>(self: Self, init: Acc, fold: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Acc
impl<B, I: FusedIterator, F> FusedIterator for FilterMap<I, F>
impl<B, I: Iterator, F> Iterator for FilterMap<I, F>
fn next(self: &mut Self) -> Option<B>fn next_chunk<N: usize>(self: &mut Self) -> Result<[<Self as >::Item; N], IntoIter<<Self as >::Item, N>>fn size_hint(self: &Self) -> (usize, Option<usize>)fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn fold<Acc, Fold>(self: Self, init: Acc, fold: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Acc
impl<I> IntoIterator for FilterMap<I, F>
fn into_iter(self: Self) -> I
impl<I, F> Freeze for FilterMap<I, F>
impl<I, F> RefUnwindSafe for FilterMap<I, F>
impl<I, F> Send for FilterMap<I, F>
impl<I, F> Sync for FilterMap<I, F>
impl<I, F> Unpin for FilterMap<I, F>
impl<I, F> UnsafeUnpin for FilterMap<I, F>
impl<I, F> UnwindSafe for FilterMap<I, F>
impl<I: $crate::clone::Clone, F: $crate::clone::Clone> Clone for FilterMap<I, F>
fn clone(self: &Self) -> FilterMap<I, F>
impl<I: fmt::Debug, F> Debug for FilterMap<I, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for FilterMap<I, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FilterMap<I, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FilterMap<I, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FilterMap<I, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FilterMap<I, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for FilterMap<I, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FilterMap<I, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FilterMap<I, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>