Struct Skip
struct Skip<I> { ... }
An iterator that skips over n elements of iter.
This struct is created by the skip method on Iterator. See its
documentation for more.
Implementations
impl<I> DoubleEndedIterator for Skip<I>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<I as >::Item>fn try_rfold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn rfold<AAA, FFF>(self: Self, init: AAA, fold: FFF) -> AAA where FFF: FnMut(AAA, <Self as >::Item) -> AAAfn advance_back_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>
impl<I> ExactSizeIterator for Skip<I>
impl<I> Freeze for Skip<I>
impl<I> FusedIterator for Skip<I>
impl<I> IntoIterator for Skip<I>
fn into_iter(self: Self) -> I
impl<I> Iterator for Skip<I>
fn next(self: &mut Self) -> Option<<I as >::Item>fn nth(self: &mut Self, n: usize) -> Option<<I as >::Item>fn count(self: Self) -> usizefn last(self: Self) -> Option<<I as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn try_fold<Acc, Fold, R>(self: &mut Self, init: Acc, fold: Fold) -> R where Self: Sized, Fold: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn fold<Acc, Fold>(self: Self, init: Acc, fold: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Accfn advance_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>
impl<I> RefUnwindSafe for Skip<I>
impl<I> Send for Skip<I>
impl<I> Sync for Skip<I>
impl<I> TrustedLen for Skip<I>
impl<I> Unpin for Skip<I>
impl<I> UnsafeUnpin for Skip<I>
impl<I> UnwindSafe for Skip<I>
impl<I: $crate::clone::Clone> Clone for Skip<I>
fn clone(self: &Self) -> Skip<I>
impl<I: $crate::fmt::Debug> Debug for Skip<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Skip<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Skip<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Skip<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Skip<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Skip<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Skip<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Skip<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Skip<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>