Struct StepBy
struct StepBy<I> { ... }
An iterator for stepping iterators by a custom amount.
This struct is created by the step_by method on Iterator. See
its documentation for more.
Implementations
impl<I> DoubleEndedIterator for StepBy<I>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn try_rfold<Acc, F, R>(self: &mut Self, init: Acc, f: F) -> R where F: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn rfold<Acc, F>(self: Self, init: Acc, f: F) -> Acc where Self: Sized, F: FnMut(Acc, <Self as >::Item) -> Acc
impl<I> ExactSizeIterator for StepBy<I>
impl<I> Freeze for StepBy<I>
impl<I> IntoIterator for StepBy<I>
fn into_iter(self: Self) -> I
impl<I> Iterator for StepBy<I>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn try_fold<Acc, F, R>(self: &mut Self, acc: Acc, f: F) -> R where F: FnMut(Acc, <Self as >::Item) -> R, R: Try<Output = Acc>fn fold<Acc, F>(self: Self, acc: Acc, f: F) -> Acc where F: FnMut(Acc, <Self as >::Item) -> Acc
impl<I> RefUnwindSafe for StepBy<I>
impl<I> Send for StepBy<I>
impl<I> Sync for StepBy<I>
impl<I> TrustedLen for StepBy<I>
impl<I> Unpin for StepBy<I>
impl<I> UnsafeUnpin for StepBy<I>
impl<I> UnwindSafe for StepBy<I>
impl<I: $crate::clone::Clone> Clone for StepBy<I>
fn clone(self: &Self) -> StepBy<I>
impl<I: $crate::fmt::Debug> Debug for StepBy<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for StepBy<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for StepBy<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for StepBy<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for StepBy<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for StepBy<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for StepBy<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for StepBy<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for StepBy<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>