Trait Sum

trait Sum<A = Self>: Sized

Trait to represent types that can be created by summing up an iterator.

This trait is used to implement [Iterator::sum()]. Types which implement this trait can be generated by using the sum() method on an iterator. Like FromIterator, this trait should rarely be called directly.

Required Methods

fn sum<I: Iterator<Item = A>>(iter: I) -> Self

Takes an iterator and generates Self from the elements by "summing up" the items.

Implementors