Trait UnsafeUnpin

unsafe auto trait UnsafeUnpin

Used to determine whether a type contains any UnsafePinned (or PhantomPinned) internally, but not through an indirection. This affects, for example, whether we emit noalias metadata for &mut T or not.

This is part of RFC 3467, and is tracked by #125735.

Implementors