Type Alias NonZeroI32
type NonZeroI32 = NonZero<i32>
An i32 that is known not to equal zero.
This enables some memory layout optimization.
For example, Option<NonZeroI32> is the same size as i32:
assert_eq!;
Layout
NonZeroI32 is guaranteed to have the same layout and bit validity as i32
with the exception that 0 is not a valid instance.
Option<NonZeroI32> is guaranteed to be compatible with i32,
including in FFI.
Thanks to the null pointer optimization,
NonZeroI32 and Option<NonZeroI32>
are guaranteed to have the same size and alignment:
use NonZeroI32;
assert_eq!;
assert_eq!;
Compile-time creation
Since both [Option::unwrap()] and [Option::expect()] are const, it is possible to
define a new
NonZeroI32
at compile time via:
use NonZeroI32;
const TEN: NonZeroI32 = new.expect;