Enum ControlFlow
enum ControlFlow<B, C = ()>
Used to tell an operation whether it should exit early or go on as usual.
This is used when exposing things (like graph traversals or visitors) where
you want the user to be able to choose whether to exit early.
Having the enum makes it clearer -- no more wondering "wait, what did false
mean again?" -- and allows including a value.
Similar to Option and Result, this enum can be used with the ? operator
to return immediately if the Break variant is present or otherwise continue normally
with the value inside the Continue variant.
Examples
Early-exiting from [Iterator::try_for_each]:
use ControlFlow;
let r = .try_for_each;
assert_eq!;
A basic tree traversal:
use ControlFlow;
let node = TreeNode ;
let mut sum = 0;
let res = node.traverse_inorder;
assert_eq!;
assert_eq!;
Variants
-
Continue(C) Move on to the next phase of the operation as normal.
-
Break(B) Exit the operation without running subsequent phases.
Implementations
impl<B, C> ControlFlow<B, C>
const fn is_break(self: &Self) -> boolReturns
trueif this is aBreakvariant.Examples
use ControlFlow; assert!; assert!;const fn is_continue(self: &Self) -> boolReturns
trueif this is aContinuevariant.Examples
use ControlFlow; assert!; assert!;const fn break_value(self: Self) -> Option<B> where Self:Converts the
ControlFlowinto anOptionwhich isSomeif theControlFlowwasBreakandNoneotherwise.Examples
use ControlFlow; assert_eq!; assert_eq!;const fn break_ok(self: Self) -> Result<B, C>Converts the
ControlFlowinto aResultwhich isOkif theControlFlowwasBreakandErrif otherwise.Examples
use ControlFlow; let node = TreeNode ; let res = node.find; assert_eq!;const fn map_break<T, F>(self: Self, f: F) -> ControlFlow<T, C> where F: ~const FnOnce(B) -> TMaps
ControlFlow<B, C>toControlFlow<T, C>by applying a function to the break value in case it exists.const fn continue_value(self: Self) -> Option<C> where Self:Converts the
ControlFlowinto anOptionwhich isSomeif theControlFlowwasContinueandNoneotherwise.Examples
use ControlFlow; assert_eq!; assert_eq!;const fn continue_ok(self: Self) -> Result<C, B>Converts the
ControlFlowinto aResultwhich isOkif theControlFlowwasContinueandErrif otherwise.Examples
use ControlFlow; let node = TreeNode ; let res = node.validate; assert_eq!;const fn map_continue<T, F>(self: Self, f: F) -> ControlFlow<B, T> where F: ~const FnOnce(C) -> TMaps
ControlFlow<B, C>toControlFlow<B, T>by applying a function to the continue value in case it exists.
impl<T> ControlFlow<T, T>
const fn into_value(self: Self) -> TExtracts the value
Tthat is wrapped byControlFlow<T, T>.Examples
use ControlFlow; assert_eq!; assert_eq!;
impl<B, C> Freeze for ControlFlow<B, C>
impl<B, C> FromResidual for ControlFlow<B, C>
fn from_residual(residual: ControlFlow<B, Infallible>) -> Self
impl<B, C> RefUnwindSafe for ControlFlow<B, C>
impl<B, C> Residual for ControlFlow<B, Infallible>
impl<B, C> Send for ControlFlow<B, C>
impl<B, C> StructuralPartialEq for ControlFlow<B, C>
impl<B, C> Sync for ControlFlow<B, C>
impl<B, C> Try for ControlFlow<B, C>
fn from_output(output: <Self as >::Output) -> Selffn branch(self: Self) -> ControlFlow<<Self as >::Residual, <Self as >::Output>
impl<B, C> Unpin for ControlFlow<B, C>
impl<B, C> UnsafeUnpin for ControlFlow<B, C>
impl<B, C> UnwindSafe for ControlFlow<B, C>
impl<B: $crate::fmt::Debug, C: $crate::fmt::Debug> Debug for ControlFlow<B, C>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<B: $crate::hash::Hash, C: $crate::hash::Hash> Hash for ControlFlow<B, C>
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl<B: $crate::marker::Copy, C: $crate::marker::Copy> Copy for ControlFlow<B, C>
impl<B: ~const $crate::clone::Clone, C: ~const $crate::clone::Clone> Clone for ControlFlow<B, C>
fn clone(self: &Self) -> ControlFlow<B, C>
impl<B: ~const $crate::cmp::Eq, C: ~const $crate::cmp::Eq> Eq for ControlFlow<B, C>
impl<B: ~const $crate::cmp::PartialEq, C: ~const $crate::cmp::PartialEq> PartialEq for ControlFlow<B, C>
fn eq(self: &Self, other: &ControlFlow<B, C>) -> bool
impl<T> Any for ControlFlow<B, C>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ControlFlow<B, C>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ControlFlow<B, C>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ControlFlow<B, C>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ControlFlow<B, C>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ControlFlow<B, C>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ControlFlow<B, C>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ControlFlow<B, C>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>