Enum OneSidedRangeBound
enum OneSidedRangeBound
An internal helper for split_off functions indicating
which end a OneSidedRange is bounded on.
Variants
-
StartInclusive The range is bounded inclusively from below and is unbounded above.
-
End The range is bounded exclusively from above and is unbounded below.
-
EndInclusive The range is bounded inclusively from above and is unbounded below.
Implementations
impl Freeze for OneSidedRangeBound
impl RefUnwindSafe for OneSidedRangeBound
impl Send for OneSidedRangeBound
impl Sync for OneSidedRangeBound
impl Unpin for OneSidedRangeBound
impl UnsafeUnpin for OneSidedRangeBound
impl UnwindSafe for OneSidedRangeBound
impl<T> Any for OneSidedRangeBound
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for OneSidedRangeBound
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for OneSidedRangeBound
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for OneSidedRangeBound
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for OneSidedRangeBound
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for OneSidedRangeBound
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for OneSidedRangeBound
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>