Struct Range
struct Range<Idx> { ... }
A (half-open) range bounded inclusively below and exclusively above
(start..end).
The range start..end contains all values with start <= x < end.
It is empty if start >= end.
Examples
The start..end syntax is a Range:
assert_eq!;
assert_eq!;
let arr = ;
assert_eq!;
assert_eq!;
assert_eq!;
assert_eq!;
assert_eq!; // This is a `Range`
assert_eq!;
Fields
start: IdxThe lower bound of the range (inclusive).
end: IdxThe upper bound of the range (exclusive).
Implementations
impl<Idx: PartialOrd<Idx>> Range<Idx>
const fn contains<U>(self: &Self, item: &U) -> bool where Idx: ~const PartialOrd<U>, U: ?Sized + ~const PartialOrd<Idx>Returns
trueifitemis contained in the range.Examples
assert!; assert!; assert!; assert!; assert!; assert!; assert!; assert!; assert!; assert!;const fn is_empty(self: &Self) -> bool where Idx: ~const PartialOrd<Idx>Returns
trueif the range contains no items.Examples
assert!; assert!; assert!;The range is empty if either side is incomparable:
assert!; assert!; assert!;
impl ExactSizeIterator for Range<i16>
impl ExactSizeIterator for Range<i32>
impl ExactSizeIterator for Range<i8>
impl ExactSizeIterator for Range<isize>
impl ExactSizeIterator for Range<u16>
impl ExactSizeIterator for Range<u32>
impl ExactSizeIterator for Range<u8>
impl ExactSizeIterator for Range<usize>
impl GetDisjointMutIndex for Range<usize>
fn is_in_bounds(self: &Self, len: usize) -> boolfn is_overlapping(self: &Self, other: &Self) -> bool
impl SliceIndex for Range<usize>
fn get(self: Self, slice: &str) -> Option<&<Self as >::Output>fn get_mut(self: Self, slice: &mut str) -> Option<&mut <Self as >::Output>unsafe fn get_unchecked(self: Self, slice: *const str) -> *const <Self as >::Outputunsafe fn get_unchecked_mut(self: Self, slice: *mut str) -> *mut <Self as >::Outputfn index(self: Self, slice: &str) -> &<Self as >::Outputfn index_mut(self: Self, slice: &mut str) -> &mut <Self as >::Output
impl SliceIndex for Range<usize>
fn get(self: Self, slice: &ByteStr) -> Option<&<Self as >::Output>fn get_mut(self: Self, slice: &mut ByteStr) -> Option<&mut <Self as >::Output>unsafe fn get_unchecked(self: Self, slice: *const ByteStr) -> *const <Self as >::Outputunsafe fn get_unchecked_mut(self: Self, slice: *mut ByteStr) -> *mut <Self as >::Outputfn index(self: Self, slice: &ByteStr) -> &<Self as >::Outputfn index_mut(self: Self, slice: &mut ByteStr) -> &mut <Self as >::Output
impl<A: Step> DoubleEndedIterator for Range<A>
fn next_back(self: &mut Self) -> Option<A>fn nth_back(self: &mut Self, n: usize) -> Option<A>fn advance_back_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>
impl<A: Step> FusedIterator for Range<A>
impl<A: Step> Iterator for Range<A>
fn next(self: &mut Self) -> Option<A>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<A>fn last(self: Self) -> Option<A>fn min(self: Self) -> Option<A> where A: Ordfn max(self: Self) -> Option<A> where A: Ordfn is_sorted(self: Self) -> boolfn advance_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>
impl<A: TrustedStep> TrustedLen for Range<A>
impl<I> IntoIterator for Range<Idx>
fn into_iter(self: Self) -> I
impl<Idx> Freeze for Range<Idx>
impl<Idx> RefUnwindSafe for Range<Idx>
impl<Idx> Send for Range<Idx>
impl<Idx> StructuralPartialEq for Range<Idx>
impl<Idx> Sync for Range<Idx>
impl<Idx> Unpin for Range<Idx>
impl<Idx> UnsafeUnpin for Range<Idx>
impl<Idx> UnwindSafe for Range<Idx>
impl<Idx: $crate::cmp::Eq> Eq for Range<Idx>
impl<Idx: $crate::hash::Hash> Hash for Range<Idx>
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl<Idx: fmt::Debug> Debug for Range<Idx>
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl<Idx: ~const $crate::clone::Clone> Clone for Range<Idx>
fn clone(self: &Self) -> Range<Idx>
impl<Idx: ~const $crate::cmp::PartialEq> PartialEq for Range<Idx>
fn eq(self: &Self, other: &Range<Idx>) -> bool
impl<Idx: ~const $crate::default::Default> Default for Range<Idx>
fn default() -> Range<Idx>
impl<T> Any for Range<Idx>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Range<Idx>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Range<Idx>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Range<Idx>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Range<Idx>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> From for Range<T>
fn from(value: Range<T>) -> Self
impl<T> IntoBounds for Range<T>
fn into_bounds(self: Self) -> (Bound<T>, Bound<T>)
impl<T> RangeBounds for Range<&T>
fn start_bound(self: &Self) -> Bound<&T>fn end_bound(self: &Self) -> Bound<&T>
impl<T> RangeBounds for Range<T>
fn start_bound(self: &Self) -> Bound<&T>fn end_bound(self: &Self) -> Bound<&T>
impl<T> SliceIndex for Range<usize>
fn get(self: Self, slice: &[T]) -> Option<&[T]>fn get_mut(self: Self, slice: &mut [T]) -> Option<&mut [T]>unsafe fn get_unchecked(self: Self, slice: *const [T]) -> *const [T]unsafe fn get_unchecked_mut(self: Self, slice: *mut [T]) -> *mut [T]fn index(self: Self, slice: &[T]) -> &[T]fn index_mut(self: Self, slice: &mut [T]) -> &mut [T]
impl<T, U> Into for Range<Idx>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Range<Idx>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Range<Idx>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>