Trait CoerceShared

trait CoerceShared: Reborrow

Allows reborrowable value to be reborrowed as shared, creating a copy that disables the source for writes for the lifetime of the copy.

Associated Types

type Target: TraitBound { trait_: Path { path: "Copy", id: Id(6), args: None }, generic_params: [], modifier: None }

The type of this value when reborrowed as shared.