Struct PanicInfo
struct PanicInfo<'a> { ... }
A struct providing information about a panic.
A PanicInfo structure is passed to the panic handler defined by #[panic_handler].
For the type used by the panic hook mechanism in std, see std::panic::PanicHookInfo.
Implementations
impl<'a> PanicInfo<'a>
fn message(self: &Self) -> PanicMessage<'_>The message that was given to the
panic!macro.Example
The type returned by this method implements
Display, so it can be passed directly towrite!()and similar macros.#[panic_handler] fn panic_handler(panic_info: &PanicInfo<'_>) -> ! { write!(DEBUG_OUTPUT, "panicked: {}", panic_info.message()); loop {} }fn location(self: &Self) -> Option<&Location<'_>>Returns information about the location from which the panic originated, if available.
This method will currently always return
Some, but this may change in future versions.Examples
use std::panic; panic::set_hook(Box::new(|panic_info| { if let Some(location) = panic_info.location() { println!("panic occurred in file '{}' at line {}", location.file(), location.line(), ); } else { println!("panic occurred but can't get location information..."); } })); panic!("Normal panic");fn payload(self: &Self) -> &dyn Any + SendReturns the payload associated with the panic.
On this type,
core::panic::PanicInfo, this method never returns anything useful. It only exists because of compatibility withstd::panic::PanicHookInfo, which used to be the same type.fn can_unwind(self: &Self) -> boolReturns whether the panic handler is allowed to unwind the stack from the point where the panic occurred.
This is true for most kinds of panics with the exception of panics caused by trying to unwind out of a
Dropimplementation or a function whose ABI does not support unwinding.It is safe for a panic handler to unwind even when this function returns false, however this will simply cause the panic handler to be called again.
impl Display for PanicInfo<'_>
fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result
impl<'a> Debug for PanicInfo<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for PanicInfo<'a>
impl<'a> RefUnwindSafe for PanicInfo<'a>
impl<'a> Send for PanicInfo<'a>
impl<'a> Sync for PanicInfo<'a>
impl<'a> Unpin for PanicInfo<'a>
impl<'a> UnsafeUnpin for PanicInfo<'a>
impl<'a> UnwindSafe for PanicInfo<'a>
impl<T> Any for PanicInfo<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PanicInfo<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PanicInfo<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for PanicInfo<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for PanicInfo<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PanicInfo<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PanicInfo<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>