Struct RangeIter
struct RangeIter<A>(_)
By-value Range iterator.
Implementations
impl<A> RangeIter<A>
fn remainder(self: Self) -> Range<A>Returns the remainder of the range being iterated over.
impl ExactSizeIterator for RangeIter<i16>
impl ExactSizeIterator for RangeIter<i8>
impl ExactSizeIterator for RangeIter<isize>
impl ExactSizeIterator for RangeIter<u16>
impl ExactSizeIterator for RangeIter<u8>
impl ExactSizeIterator for RangeIter<usize>
impl<A> Freeze for RangeIter<A>
impl<A> RefUnwindSafe for RangeIter<A>
impl<A> Send for RangeIter<A>
impl<A> Sync for RangeIter<A>
impl<A> Unpin for RangeIter<A>
impl<A> UnsafeUnpin for RangeIter<A>
impl<A> UnwindSafe for RangeIter<A>
impl<A: $crate::clone::Clone> Clone for RangeIter<A>
fn clone(self: &Self) -> RangeIter<A>
impl<A: $crate::fmt::Debug> Debug for RangeIter<A>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<A: Step> DoubleEndedIterator for RangeIter<A>
fn next_back(self: &mut Self) -> Option<A>fn nth_back(self: &mut Self, n: usize) -> Option<A>fn advance_back_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>
impl<A: Step> FusedIterator for RangeIter<A>
impl<A: Step> Iterator for RangeIter<A>
fn next(self: &mut Self) -> Option<A>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<A>fn last(self: Self) -> Option<A>fn min(self: Self) -> Option<A> where A: Ordfn max(self: Self) -> Option<A> where A: Ordfn is_sorted(self: Self) -> boolfn advance_by(self: &mut Self, n: usize) -> Result<(), NonZero<usize>>
impl<A: TrustedStep> TrustedLen for RangeIter<A>
impl<I> IntoIterator for RangeIter<A>
fn into_iter(self: Self) -> I
impl<T> Any for RangeIter<A>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RangeIter<A>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RangeIter<A>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for RangeIter<A>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for RangeIter<A>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for RangeIter<A>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RangeIter<A>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RangeIter<A>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>