Struct RChunksExactMut
struct RChunksExactMut<'a, T: 'a> { ... }
An iterator over a slice in (non-overlapping) mutable chunks (chunk_size
elements at a time), starting at the end of the slice.
When the slice len is not evenly divided by the chunk size, the last up to
chunk_size-1 elements will be omitted but can be retrieved from the
into_remainder function from the iterator.
This struct is created by the rchunks_exact_mut method on slices.
Example
let mut slice = ;
let iter = slice.rchunks_exact_mut;
Implementations
impl<'a, T> RChunksExactMut<'a, T>
const fn into_remainder(self: Self) -> &'a mut [T]Returns the remainder of the original slice that is not going to be returned by the iterator. The returned slice has at most
chunk_size-1elements.
impl<'a, T> DoubleEndedIterator for RChunksExactMut<'a, T>
fn next_back(self: &mut Self) -> Option<&'a mut [T]>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<'a, T> Freeze for RChunksExactMut<'a, T>
impl<'a, T> Iterator for RChunksExactMut<'a, T>
fn next(self: &mut Self) -> Option<&'a mut [T]>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<&'a mut [T]>fn last(self: Self) -> Option<<Self as >::Item>
impl<'a, T> RefUnwindSafe for RChunksExactMut<'a, T>
impl<'a, T> Unpin for RChunksExactMut<'a, T>
impl<'a, T> UnsafeUnpin for RChunksExactMut<'a, T>
impl<'a, T> UnwindSafe for RChunksExactMut<'a, T>
impl<'a, T: $crate::fmt::Debug + 'a> Debug for RChunksExactMut<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I> IntoIterator for RChunksExactMut<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for RChunksExactMut<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RChunksExactMut<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RChunksExactMut<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ExactSizeIterator for RChunksExactMut<'_, T>
fn is_empty(self: &Self) -> bool
impl<T> From for RChunksExactMut<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for RChunksExactMut<'_, T>
impl<T> Send for RChunksExactMut<'_, T>
impl<T> Sync for RChunksExactMut<'_, T>
impl<T> TrustedLen for RChunksExactMut<'_, T>
impl<T, U> Into for RChunksExactMut<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RChunksExactMut<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RChunksExactMut<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>