Struct SplitMut
struct SplitMut<'a, T: 'a, P> { ... }
where
P: FnMut(&T) -> bool
An iterator over the mutable subslices of the vector which are separated
by elements that match pred.
This struct is created by the split_mut method on slices.
Example
let mut v = ;
let iter = v.split_mut;
Implementations
impl<'a, T, P> DoubleEndedIterator for SplitMut<'a, T, P>
fn next_back(self: &mut Self) -> Option<&'a mut [T]>
impl<'a, T, P> Freeze for SplitMut<'a, T, P>
impl<'a, T, P> Iterator for SplitMut<'a, T, P>
fn next(self: &mut Self) -> Option<&'a mut [T]>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'a, T, P> RefUnwindSafe for SplitMut<'a, T, P>
impl<'a, T, P> Send for SplitMut<'a, T, P>
impl<'a, T, P> Sync for SplitMut<'a, T, P>
impl<'a, T, P> Unpin for SplitMut<'a, T, P>
impl<'a, T, P> UnsafeUnpin for SplitMut<'a, T, P>
impl<'a, T, P> UnwindSafe for SplitMut<'a, T, P>
impl<I> IntoIterator for SplitMut<'a, T, P>
fn into_iter(self: Self) -> I
impl<T> Any for SplitMut<'a, T, P>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SplitMut<'a, T, P>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SplitMut<'a, T, P>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for SplitMut<'a, T, P>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, P> FusedIterator for SplitMut<'_, T, P>
impl<T, U> Into for SplitMut<'a, T, P>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SplitMut<'a, T, P>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SplitMut<'a, T, P>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: fmt::Debug, P> Debug for SplitMut<'_, T, P>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result