Struct Bytes
struct Bytes<'a>(_)
An iterator over the bytes of a string slice.
This struct is created by the bytes method on str.
See its documentation for more.
Implementations
impl DoubleEndedIterator for Bytes<'_>
fn next_back(self: &mut Self) -> Option<u8>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn rfind<P>(self: &mut Self, predicate: P) -> Option<<Self as >::Item> where P: FnMut(&<Self as >::Item) -> bool
impl ExactSizeIterator for Bytes<'_>
fn len(self: &Self) -> usizefn is_empty(self: &Self) -> bool
impl FusedIterator for Bytes<'_>
impl Iterator for Bytes<'_>
fn next(self: &mut Self) -> Option<u8>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn last(self: Self) -> Option<<Self as >::Item>fn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn all<F>(self: &mut Self, f: F) -> bool where F: FnMut(<Self as >::Item) -> boolfn any<F>(self: &mut Self, f: F) -> bool where F: FnMut(<Self as >::Item) -> boolfn find<P>(self: &mut Self, predicate: P) -> Option<<Self as >::Item> where P: FnMut(&<Self as >::Item) -> boolfn position<P>(self: &mut Self, predicate: P) -> Option<usize> where P: FnMut(<Self as >::Item) -> boolfn rposition<P>(self: &mut Self, predicate: P) -> Option<usize> where P: FnMut(<Self as >::Item) -> bool
impl TrustedLen for Bytes<'_>
impl<'a> Clone for Bytes<'a>
fn clone(self: &Self) -> Bytes<'a>
impl<'a> Debug for Bytes<'a>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a> Freeze for Bytes<'a>
impl<'a> RefUnwindSafe for Bytes<'a>
impl<'a> Send for Bytes<'a>
impl<'a> Sync for Bytes<'a>
impl<'a> Unpin for Bytes<'a>
impl<'a> UnsafeUnpin for Bytes<'a>
impl<'a> UnwindSafe for Bytes<'a>
impl<I> IntoIterator for Bytes<'a>
fn into_iter(self: Self) -> I
impl<T> Any for Bytes<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Bytes<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Bytes<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Bytes<'a>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Bytes<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Bytes<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Bytes<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Bytes<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>