Struct LocalWaker
struct LocalWaker { ... }
A LocalWaker is analogous to a Waker, but it does not implement Send or Sync.
This handle encapsulates a RawWaker instance, which defines the
executor-specific wakeup behavior.
Local wakers can be requested from a Context with the local_waker method.
The typical life of a LocalWaker is that it is constructed by an executor, wrapped in a
Context using ContextBuilder, then passed to Future::poll(). Then, if the future chooses to return
Poll::Pending, it must also store the waker somehow and call [LocalWaker::wake()] when
the future should be polled again.
Implements Clone, but neither Send nor Sync; therefore, a local waker may
not be moved to other threads. In general, when deciding to use wakers or local wakers,
local wakers are preferable unless the waker needs to be sent across threads. This is because
wakers can incur in additional cost related to memory synchronization.
Note that it is preferable to use local_waker.clone_from(&new_waker) instead
of *local_waker = new_waker.clone(), as the former will avoid cloning the waker
unnecessarily if the two wakers wake the same task.
Examples
Usage of a local waker to implement a future analogous to std::thread::yield_now().
use ;
use Poll;
// a future that returns pending once.
+ Unpin
# async
Implementations
impl LocalWaker
fn wake(self: Self)Wakes up the task associated with this
LocalWaker.As long as the executor keeps running and the task is not finished, it is guaranteed that each invocation of
wake()(orwake_by_ref()) will be followed by at least onepoll()of the task to which thisLocalWakerbelongs. This makes it possible to temporarily yield to other tasks while running potentially unbounded processing loops.Note that the above implies that multiple wake-ups may be coalesced into a single
poll()invocation by the runtime.Also note that yielding to competing tasks is not guaranteed: it is the executor’s choice which task to run and the executor may choose to run the current task again.
fn wake_by_ref(self: &Self)Wakes up the task associated with this
LocalWakerwithout consuming theLocalWaker.This is similar to
wake(), but may be slightly less efficient in the case where an ownedWakeris available. This method should be preferred to callingwaker.clone().wake().fn will_wake(self: &Self, other: &LocalWaker) -> boolReturns
trueif thisLocalWakerand anotherLocalWakerwould awake the same task.This function works on a best-effort basis, and may return false even when the
Wakers would awaken the same task. However, if this function returnstrue, it is guaranteed that theWakers will awaken the same task.This function is primarily used for optimization purposes — for example, this type's
clone_fromimplementation uses it to avoid cloning the waker when they would wake the same task anyway.unsafe const fn new(data: *const (), vtable: &'static RawWakerVTable) -> SelfCreates a new
LocalWakerfrom the provideddatapointer andvtable.The
datapointer can be used to store arbitrary data as required by the executor. This could be e.g. a type-erased pointer to anArcthat is associated with the task. The value of this pointer will get passed to all functions that are part of thevtableas the first parameter.The
vtablecustomizes the behavior of aLocalWaker. For each operation on theLocalWaker, the associated function in thevtablewill be called.Safety
The behavior of the returned
Wakeris undefined if the contract defined inRawWakerVTable's documentation is not upheld.unsafe const fn from_raw(waker: RawWaker) -> LocalWakerCreates a new
LocalWakerfromRawWaker.The behavior of the returned
LocalWakeris undefined if the contract defined inRawWaker's andRawWakerVTable's documentation is not upheld. Therefore this method is unsafe.const fn noop() -> &'static LocalWakerReturns a reference to a
LocalWakerthat does nothing when used.This is mostly useful for writing tests that need a
Contextto poll some futures, but are not expecting those futures to wake the waker or do not need to do anything specific if it happens.More generally, using
LocalWaker::noop()to poll a future means discarding the notification of when the future should be polled again, So it should only be used when such a notification will not be needed to make progress.If an owned
LocalWakeris needed,clone()this one.Examples
use Future; use ; let mut cx = from_waker .local_waker .build; let mut future = Boxpin; assert_eq!;fn data(self: &Self) -> *const ()Gets the
datapointer used to create thisLocalWaker.fn vtable(self: &Self) -> &'static RawWakerVTableGets the
vtablepointer used to create thisLocalWaker.const fn from_fn_ptr(f: fn()) -> SelfConstructs a
LocalWakerfrom a function pointer.
impl Clone for LocalWaker
fn clone(self: &Self) -> Selffn clone_from(self: &mut Self, source: &Self)
impl Debug for LocalWaker
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Drop for LocalWaker
fn drop(self: &mut Self)
impl Freeze for LocalWaker
impl RefUnwindSafe for LocalWaker
impl Send for LocalWaker
impl Sync for LocalWaker
impl Unpin for LocalWaker
impl UnsafeUnpin for LocalWaker
impl UnwindSafe for LocalWaker
impl<T> Any for LocalWaker
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for LocalWaker
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for LocalWaker
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for LocalWaker
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for LocalWaker
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for LocalWaker
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for LocalWaker
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for LocalWaker
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>