Struct Waker
struct Waker { ... }
A Waker is a handle for waking up a task by notifying its executor that it
is ready to be run.
This handle encapsulates a RawWaker instance, which defines the
executor-specific wakeup behavior.
The typical life of a Waker is that it is constructed by an executor, wrapped in a
Context, then passed to Future::poll(). Then, if the future chooses to return
Poll::Pending, it must also store the waker somehow and call [Waker::wake()] when
the future should be polled again.
Implements Clone, Send, and Sync; therefore, a waker may be invoked
from any thread, including ones not in any way managed by the executor. For example,
this might be done to wake a future when a blocking function call completes on another
thread.
Note that it is preferable to use waker.clone_from(&new_waker) instead
of *waker = new_waker.clone(), as the former will avoid cloning the waker
unnecessarily if the two wakers wake the same task.
Constructing a Waker from a RawWaker is unsafe.
Implementing the Wake trait is a safe alternative that requires memory allocation.
Implementations
impl Waker
fn wake(self: Self)Wakes up the task associated with this
Waker.As long as the executor keeps running and the task is not finished, it is guaranteed that each invocation of
wake()(orwake_by_ref()) will be followed by at least onepoll()of the task to which thisWakerbelongs. This makes it possible to temporarily yield to other tasks while running potentially unbounded processing loops.Note that the above implies that multiple wake-ups may be coalesced into a single
poll()invocation by the runtime.Also note that yielding to competing tasks is not guaranteed: it is the executor’s choice which task to run and the executor may choose to run the current task again.
fn wake_by_ref(self: &Self)Wakes up the task associated with this
Wakerwithout consuming theWaker.This is similar to
wake(), but may be slightly less efficient in the case where an ownedWakeris available. This method should be preferred to callingwaker.clone().wake().fn will_wake(self: &Self, other: &Waker) -> boolReturns
trueif thisWakerand anotherWakerwould awake the same task.This function works on a best-effort basis, and may return false even when the
Wakers would awaken the same task. However, if this function returnstrue, it is guaranteed that theWakers will awaken the same task.This function is primarily used for optimization purposes — for example, this type's
clone_fromimplementation uses it to avoid cloning the waker when they would wake the same task anyway.unsafe const fn new(data: *const (), vtable: &'static RawWakerVTable) -> SelfCreates a new
Wakerfrom the provideddatapointer andvtable.The
datapointer can be used to store arbitrary data as required by the executor. This could be e.g. a type-erased pointer to anArcthat is associated with the task. The value of this pointer will get passed to all functions that are part of thevtableas the first parameter.It is important to consider that the
datapointer must point to a thread safe type such as anArc.The
vtablecustomizes the behavior of aWaker. For each operation on theWaker, the associated function in thevtablewill be called.Safety
The behavior of the returned
Wakeris undefined if the contract defined inRawWakerVTable's documentation is not upheld.(Authors wishing to avoid unsafe code may implement the
Waketrait instead, at the cost of a required heap allocation.)unsafe const fn from_raw(waker: RawWaker) -> WakerCreates a new
WakerfromRawWaker.Safety
The behavior of the returned
Wakeris undefined if the contract defined inRawWaker's andRawWakerVTable's documentation is not upheld.(Authors wishing to avoid unsafe code may implement the
Waketrait instead, at the cost of a required heap allocation.)const fn noop() -> &'static WakerReturns a reference to a
Wakerthat does nothing when used.This is mostly useful for writing tests that need a
Contextto poll some futures, but are not expecting those futures to wake the waker or do not need to do anything specific if it happens.More generally, using
Waker::noop()to poll a future means discarding the notification of when the future should be polled again. So it should only be used when such a notification will not be needed to make progress.If an owned
Wakeris needed,clone()this one.Examples
use Future; use task; let mut cx = from_waker; let mut future = Boxpin; assert_eq!;fn data(self: &Self) -> *const ()Gets the
datapointer used to create thisWaker.fn vtable(self: &Self) -> &'static RawWakerVTableGets the
vtablepointer used to create thisWaker.const fn from_fn_ptr(f: fn()) -> SelfConstructs a
Wakerfrom a function pointer.
impl AsRef for Waker
fn as_ref(self: &Self) -> &LocalWaker
impl Clone for Waker
fn clone(self: &Self) -> Selffn clone_from(self: &mut Self, source: &Self)Assigns a clone of
sourcetoself, unless [self.will_wake(source)][Waker::will_wake] anyway.This method is preferred over simply assigning
source.clone()toself, as it avoids cloning the waker ifselfis already the same waker.Examples
use Future; use Pin; use ; use ;
impl Debug for Waker
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Drop for Waker
fn drop(self: &mut Self)
impl Freeze for Waker
impl RefUnwindSafe for Waker
impl Send for Waker
impl Sync for Waker
impl Unpin for Waker
impl UnsafeUnpin for Waker
impl UnwindSafe for Waker
impl<T> Any for Waker
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Waker
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Waker
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Waker
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Waker
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Waker
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Waker
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Waker
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>